@@ -158,7 +158,7 @@ def print_used_values(cfg, log):
 
 
 def fill_cfg(options_to_parse, log, secondary_filling=False):
-    skip_output_dir=secondary_filling
+    skip_output_dir = secondary_filling
     skip_stop_after = secondary_filling
     load_processed_dataset=secondary_filling
 
@@ -186,10 +186,15 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
                                       len(options_storage.SHORT_READS_TYPES.keys()) +
                                       len(options_storage.LONG_READS_TYPES))]  # "[{}]*num" doesn't work here!
 
+    # auto detecting SPAdes mode (rna, meta, etc) if it is not a rerun (--continue or --restart-from)
+    if secondary_filling or not options_storage.will_rerun(options):
+        mode = options_storage.get_mode()
+        if mode is not None:
+            options.append(('--' + mode, ''))
+
     # for parsing options from "previous run command"
     options_storage.continue_mode = False
     options_storage.k_mers = None
-
     for opt, arg in options:
         if opt == '-o':
             if not skip_output_dir:
@@ -197,13 +202,18 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
                     support.error('-o option was specified at least twice')
                 options_storage.output_dir = abspath(expanduser(arg))
                 options_storage.dict_of_rel2abs[arg] = options_storage.output_dir
+                support.check_path_is_ascii(options_storage.output_dir, 'output directory')
         elif opt == "--tmp-dir":
             options_storage.tmp_dir = abspath(expanduser(arg))
             options_storage.dict_of_rel2abs[arg] = options_storage.tmp_dir
+            support.check_path_is_ascii(options_storage.tmp_dir, 'directory for temporary files')
         elif opt == "--configs-dir":
             options_storage.configs_dir = support.check_dir_existence(arg)
         elif opt == "--reference":
             options_storage.reference = support.check_file_existence(arg, 'reference', log)
+            options_storage.developer_mode = True
+        elif opt == "--series-analysis":
+            options_storage.series_analysis = support.check_file_existence(arg, 'series-analysis', log)
         elif opt == "--dataset":
             options_storage.dataset_yaml_filename = support.check_file_existence(arg, 'dataset', log)
 
@@ -225,17 +235,24 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
         elif opt == "--sc":
             options_storage.single_cell = True
         elif opt == "--meta":
-            #FIXME temporary solution
-            options_storage.single_cell = True
             options_storage.meta = True
         elif opt == "--large-genome":
             options_storage.large_genome = True
         elif opt == "--plasmid":
             options_storage.plasmid = True
+
         elif opt == "--rna":
-            #FIXME temporary solution
-            options_storage.single_cell = True
             options_storage.rna = True
+        elif opt.startswith("--ss-"):  # strand specificity, RNA-Seq only
+            if opt == "--ss-rf":
+                options_storage.strand_specific = True
+            elif opt == "--ss-fr":
+                options_storage.strand_specific = False
+        elif opt == "--fast":  # fast run, RNA-Seq only
+            options_storage.fast = True
+        elif opt == "--fast:false":
+            options_storage.fast = False
+
         elif opt == "--iontorrent":
             options_storage.iontorrent = True
         elif opt == "--disable-gzip-output":
@@ -290,6 +307,8 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
             else:
                 support.error('wrong PHRED quality offset value: ' + arg +
                               ' (should be either 33, 64, or \'auto\')', log)
+        elif opt == "--save-gp":
+            options_storage.save_gp = True
         elif opt == "--cov-cutoff":
             if arg == 'auto' or arg == 'off':
                 options_storage.cov_cutoff = arg
@@ -298,6 +317,12 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
             else:
                 support.error('wrong value for --cov-cutoff option: ' + arg +
                               ' (should be a positive float number, or \'auto\', or \'off\')', log)
+        elif opt == "--hidden-cov-cutoff":
+            if support.is_float(arg) and float(arg) > 0.0:
+                options_storage.lcer_cutoff = float(arg)
+            else:
+                support.error('wrong value for --hidden-cov-cutoff option: ' + arg +
+                              ' (should be a positive float number)', log)
         elif opt == '-i' or opt == "--iterations":
             options_storage.iterations = int(arg)
 
@@ -327,9 +352,7 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
             show_usage(0, show_hidden=True)
 
         elif opt == "--test":
-            options_storage.set_test_options()
-            support.add_to_dataset('-1', os.path.join(spades_home, "test_dataset/ecoli_1K_1.fq.gz"), dataset_data)
-            support.add_to_dataset('-2', os.path.join(spades_home, "test_dataset/ecoli_1K_2.fq.gz"), dataset_data)
+            options_storage.set_test_options()            
             #break
         elif opt == "--diploid":
             options_storage.diploid_mode = True
@@ -338,6 +361,14 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
         else:
             raise ValueError
 
+    if options_storage.test_mode:
+        if options_storage.plasmid:
+            support.add_to_dataset('-1', os.path.join(spades_home, "test_dataset_plasmid/pl1.fq.gz"), dataset_data)
+            support.add_to_dataset('-2', os.path.join(spades_home, "test_dataset_plasmid/pl2.fq.gz"), dataset_data)
+        else:
+            support.add_to_dataset('-1', os.path.join(spades_home, "test_dataset/ecoli_1K_1.fq.gz"), dataset_data)
+            support.add_to_dataset('-2', os.path.join(spades_home, "test_dataset/ecoli_1K_2.fq.gz"), dataset_data)
+
     if not options_storage.output_dir:
         support.error("the output_dir is not set! It is a mandatory parameter (-o output_dir).", log)
     if not os.path.isdir(options_storage.output_dir):
@@ -345,7 +376,7 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
             support.error("the output_dir should exist for --continue and for --restart-from!", log)
         os.makedirs(options_storage.output_dir)
     if options_storage.restart_from:
-        if options_storage.continue_mode: # saving parameters specified with --restart-from
+        if options_storage.continue_mode:  # saving parameters specified with --restart-from
             if not support.dataset_is_empty(dataset_data):
                 support.error("you cannot specify reads with --restart-from option!", log)
             options_storage.save_restart_options(log)
@@ -354,6 +385,15 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
     if options_storage.meta:
         if options_storage.careful or options_storage.mismatch_corrector or options_storage.cov_cutoff != "off":
             support.error("you cannot specify --careful, --mismatch-correction or --cov-cutoff in metagenomic mode!", log)
+    if options_storage.rna:
+        if options_storage.careful:
+            support.error("you cannot specify --careful in RNA-Seq mode!", log)
+        if options_storage.k_mers and options_storage.k_mers != 'auto' and len(options_storage.k_mers) > 1:
+            support.error("you cannot specify multiple k-mer sizes in RNA-Seq mode!", log)
+    if [options_storage.meta, options_storage.large_genome, options_storage.truseq_mode,
+       options_storage.rna, options_storage.plasmid, options_storage.single_cell].count(True) > 1:
+        support.error("you cannot simultaneously use more than one mode out of "
+                      "Metagenomic, Large genome, Illumina TruSeq, RNA-Seq, Plasmid, and Single-cell!", log)
     if options_storage.continue_mode:
         return None, None
 
@@ -367,7 +407,6 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
                 existing_dataset_data = None
     if existing_dataset_data is not None:
         dataset_data = existing_dataset_data
-        options_storage.dataset_yaml_filename = processed_dataset_fpath
     else:
         if options_storage.dataset_yaml_filename:
             try:
@@ -379,12 +418,21 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
         else:
             dataset_data = support.correct_dataset(dataset_data)
             dataset_data = support.relative2abs_paths(dataset_data, os.getcwd())
-        options_storage.dataset_yaml_filename = processed_dataset_fpath
-        pyyaml.dump(dataset_data, open(options_storage.dataset_yaml_filename, 'w'))
+    options_storage.dataset_yaml_filename = processed_dataset_fpath
 
     support.check_dataset_reads(dataset_data, options_storage.only_assembler, log)
     if not support.get_lib_ids_by_type(dataset_data, spades_logic.READS_TYPES_USED_IN_CONSTRUCTION):
         support.error('you should specify at least one unpaired, paired-end, or high-quality mate-pairs library!')
+    if options_storage.rna:
+        if len(dataset_data) != len(support.get_lib_ids_by_type(dataset_data, spades_logic.READS_TYPES_USED_IN_RNA_SEQ)):
+            support.error('you cannot specify any data types except ' +
+                          ', '.join(spades_logic.READS_TYPES_USED_IN_RNA_SEQ) + ' in RNA-Seq mode!')
+        #if len(support.get_lib_ids_by_type(dataset_data, 'paired-end')) > 1:
+        #    support.error('you cannot specify more than one paired-end library in RNA-Seq mode!')
+
+    if existing_dataset_data is None:
+        pyyaml.dump(dataset_data, open(options_storage.dataset_yaml_filename, 'w'),
+                    default_flow_style=False, default_style='"', width=float("inf"))
 
     options_storage.set_default_values()
     ### FILLING cfg
@@ -401,6 +449,8 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
     cfg["common"].__dict__["max_threads"] = options_storage.threads
     cfg["common"].__dict__["max_memory"] = options_storage.memory
     cfg["common"].__dict__["developer_mode"] = options_storage.developer_mode
+    if options_storage.series_analysis:
+        cfg["common"].__dict__["series_analysis"] = options_storage.series_analysis
 
     # dataset section
     cfg["dataset"].__dict__["yaml_filename"] = options_storage.dataset_yaml_filename
@@ -419,6 +469,8 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
         cfg["error_correction"].__dict__["iontorrent"] = options_storage.iontorrent
         if options_storage.meta or options_storage.large_genome:
             cfg["error_correction"].__dict__["count_filter_singletons"] = 1
+        if options_storage.read_buffer_size:
+            cfg["error_correction"].__dict__["read_buffer_size"] = options_storage.read_buffer_size
 
     # assembly
     if not options_storage.only_error_correction:
@@ -426,19 +478,34 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
             options_storage.k_mers = None
         if options_storage.k_mers:
             cfg["assembly"].__dict__["iterative_K"] = options_storage.k_mers
+        elif options_storage.rna:
+            k_value = options_storage.K_MERS_RNA[0]
+            if not options_storage.iontorrent:
+                k_value = int(support.get_reads_length(dataset_data, log) / 2) - 1
+                if k_value % 2 == 0:
+                    k_value -= 1
+                if k_value < options_storage.MIN_K:
+                    log.info("\n" + 'Default k value (' + str(k_value) + ') is too small, all k values should be between %d and %d. Setting k=%d.\n'
+                             % (options_storage.MIN_K, options_storage.MAX_K, options_storage.MIN_K))
+                    k_value = options_storage.MIN_K
+                if k_value > options_storage.MAX_K:
+                    log.info("\n" + 'Default k value (' + str(k_value) + ') is too large, all k values should be between %d and %d. Setting k=%d.\n'
+                             % (options_storage.MIN_K, options_storage.MAX_K, options_storage.MAX_K))
+                    k_value = options_storage.MAX_K
+            cfg["assembly"].__dict__["iterative_K"] = k_value
         else:
             cfg["assembly"].__dict__["iterative_K"] = options_storage.K_MERS_SHORT
         cfg["assembly"].__dict__["disable_rr"] = options_storage.disable_rr
         cfg["assembly"].__dict__["diploid_mode"] = options_storage.diploid_mode
         cfg["assembly"].__dict__["cov_cutoff"] = options_storage.cov_cutoff
+        cfg["assembly"].__dict__["lcer_cutoff"] = options_storage.lcer_cutoff
+        cfg["assembly"].__dict__["save_gp"] = options_storage.save_gp
         if options_storage.spades_heap_check:
             cfg["assembly"].__dict__["heap_check"] = options_storage.spades_heap_check
         if options_storage.read_buffer_size:
             cfg["assembly"].__dict__["read_buffer_size"] = options_storage.read_buffer_size
         cfg["assembly"].__dict__["correct_scaffolds"] = options_storage.correct_scaffolds
-        if options_storage.large_genome:
-            cfg["assembly"].__dict__["bwa_paired"] = True
-            cfg["assembly"].__dict__["scaffolding_mode"] = "old_pe_2015"
+
     #corrector can work only if contigs exist (not only error correction)
     if (not options_storage.only_error_correction) and options_storage.mismatch_corrector:
         cfg["mismatch_corrector"] = empty_config()
@@ -487,9 +554,11 @@ def check_cfg_for_partial_run(cfg, type='restart-from'):  # restart-from ot stop
                 support.error("failed to " + action + " K=%s because this K " % k_str + verb + " not specified!")
 
 
-def get_options_from_params(params_filename, spades_py_name=None):
+def get_options_from_params(params_filename, running_script):
+    cmd_line = None
+    options = None
     if not os.path.isfile(params_filename):
-        return None, None
+        return cmd_line, options, "failed to parse command line of the previous run (%s not found)!" % params_filename
     params = open(params_filename, 'r')
     cmd_line = params.readline().strip()
     spades_prev_version = None
@@ -499,20 +568,22 @@ def get_options_from_params(params_filename, spades_py_name=None):
             break
     params.close()
     if spades_prev_version is None:
-        support.error("failed to parse SPAdes version of the previous run! "
-                      "Please restart from the beginning or specify another output directory.")
+        return cmd_line, options, "failed to parse SPAdes version of the previous run!"
     if spades_prev_version.strip() != spades_version.strip():
-        support.error("SPAdes version of the previous run (%s) is not equal to the current version of SPAdes (%s)! "
-                      "Please restart from the beginning or specify another output directory."
-                      % (spades_prev_version.strip(), spades_version.strip()))
-    if spades_py_name is None or cmd_line.find(os.path.basename(spades_py_name)) == -1:
-        spades_py_name = 'spades.py'  # try default name
-    else:
-        spades_py_name = os.path.basename(spades_py_name)
-    spades_py_pos = cmd_line.find(spades_py_name)
-    if spades_py_pos == -1:
-        return None, None
-    return cmd_line, cmd_line[spades_py_pos + len(spades_py_name):].split('\t')
+        return cmd_line, options, "SPAdes version of the previous run (%s) is not equal " \
+                                  "to the current version of SPAdes (%s)!" \
+                                  % (spades_prev_version.strip(), spades_version.strip())
+    if 'Command line: ' not in cmd_line or '\t' not in cmd_line:
+        return cmd_line, options, "failed to parse executable script of the previous run!"
+    options = cmd_line.split('\t')[1:]
+    prev_running_script = cmd_line.split('\t')[0][len('Command line: '):]
+    # we cannot restart/continue spades.py run with metaspades.py/rnaspades.py/etc and vice versa
+    if os.path.basename(prev_running_script) != os.path.basename(running_script):
+        return cmd_line, options, "executable script of the previous run (%s) is not equal " \
+                                  "to the current executable script (%s)!" \
+                                  % (os.path.basename(prev_running_script),
+                                     os.path.basename(running_script))
+    return cmd_line, options, ""
 
 
 def show_version():
@@ -541,19 +612,14 @@ def main(args):
 
     support.check_binaries(bin_home, log)
 
-    # auto detecting SPAdes mode (rna, meta, etc)
-    mode = options_storage.get_mode()
-    if mode is not None:
-        args.append('--' + mode)
-
     # parse options and safe all parameters to cfg
     options = args
     cfg, dataset_data = fill_cfg(options, log)
 
     if options_storage.continue_mode:
-        cmd_line, options = get_options_from_params(os.path.join(options_storage.output_dir, "params.txt"), args[0])
-        if not options:
-            support.error("failed to parse command line of the previous run! Please restart from the beginning or specify another output directory.")
+        cmd_line, options, err_msg = get_options_from_params(os.path.join(options_storage.output_dir, "params.txt"), args[0])
+        if err_msg:
+            support.error(err_msg + " Please restart from the beginning or specify another output directory.")
         cfg, dataset_data = fill_cfg(options, log, secondary_filling=True)
         if options_storage.restart_from:
             check_cfg_for_partial_run(cfg, type='restart-from')
@@ -632,7 +698,8 @@ def main(args):
         if support.dataset_has_additional_contigs(dataset_data):
             dataset_data = support.process_Ns_in_additional_contigs(dataset_data, dir_for_split_reads, log)
         options_storage.dataset_yaml_filename = os.path.join(options_storage.output_dir, "input_dataset.yaml")
-        pyyaml.dump(dataset_data, open(options_storage.dataset_yaml_filename, 'w'))
+        pyyaml.dump(dataset_data, open(options_storage.dataset_yaml_filename, 'w'),
+                    default_flow_style=False, default_style='"', width=float("inf"))
         cfg["dataset"].yaml_filename = options_storage.dataset_yaml_filename
 
     try:
@@ -686,8 +753,11 @@ def main(args):
         result_contigs_filename = os.path.join(cfg["common"].output_dir, options_storage.contigs_name)
         result_scaffolds_filename = os.path.join(cfg["common"].output_dir, options_storage.scaffolds_name)
         result_assembly_graph_filename = os.path.join(cfg["common"].output_dir, options_storage.assembly_graph_name)
+        result_assembly_graph_filename_gfa = os.path.join(cfg["common"].output_dir, options_storage.assembly_graph_name_gfa)
         result_contigs_paths_filename = os.path.join(cfg["common"].output_dir, options_storage.contigs_paths)
         result_scaffolds_paths_filename = os.path.join(cfg["common"].output_dir, options_storage.scaffolds_paths)
+        result_transcripts_filename = os.path.join(cfg["common"].output_dir, options_storage.transcripts_name)
+        result_transcripts_paths_filename = os.path.join(cfg["common"].output_dir, options_storage.transcripts_paths)
         truseq_long_reads_file_base = os.path.join(cfg["common"].output_dir, "truseq_long_reads")
         truseq_long_reads_file = truseq_long_reads_file_base + ".fasta"
         misc_dir = os.path.join(cfg["common"].output_dir, "misc")
@@ -700,8 +770,11 @@ def main(args):
             spades_cfg.__dict__["result_contigs"] = result_contigs_filename
             spades_cfg.__dict__["result_scaffolds"] = result_scaffolds_filename
             spades_cfg.__dict__["result_graph"] = result_assembly_graph_filename
+            spades_cfg.__dict__["result_graph_gfa"] = result_assembly_graph_filename_gfa
             spades_cfg.__dict__["result_contigs_paths"] = result_contigs_paths_filename
             spades_cfg.__dict__["result_scaffolds_paths"] = result_scaffolds_paths_filename
+            spades_cfg.__dict__["result_transcripts"] = result_transcripts_filename
+            spades_cfg.__dict__["result_transcripts_paths"] = result_transcripts_paths_filename
 
             if options_storage.continue_mode and (os.path.isfile(spades_cfg.result_contigs)
                                                   or ("mismatch_corrector" in cfg and
@@ -827,7 +900,9 @@ def main(args):
                         if options_storage.continue_mode and os.path.isfile(corrected):
                             log.info("\n== Skipping processing of " + assembly_type + " (already processed)\n")
                             continue
-
+                        if not os.path.isfile(assembled) or os.path.getsize(assembled) == 0:
+                            log.info("\n== Skipping processing of " + assembly_type + " (empty file)\n")
+                            continue
                         support.continue_from_here(log)
                         log.info("\n== Processing of " + assembly_type + "\n")
 
@@ -838,7 +913,6 @@ def main(args):
                         corr_cfg = merge_configs(cfg["mismatch_corrector"], cfg["common"])
                         
                         result_corrected_filename = os.path.join(tmp_dir_for_corrector, "corrected_contigs.fasta")
-
                         corrector_logic.run_corrector( tmp_configs_dir, bin_home, corr_cfg,
                         ext_python_modules_home, log, assembled, result_corrected_filename)
 
@@ -861,20 +935,40 @@ def main(args):
             if "assembly" in cfg and os.path.isfile(result_contigs_filename):
                 message = " * Assembled contigs are in " + support.process_spaces(result_contigs_filename)
                 log.info(message)
-            if "assembly" in cfg and os.path.isfile(result_scaffolds_filename):
-                message = " * Assembled scaffolds are in " + support.process_spaces(result_scaffolds_filename)
-                log.info(message)
-            if "assembly" in cfg and os.path.isfile(result_assembly_graph_filename):
-                message = " * Assembly graph is in " + support.process_spaces(result_assembly_graph_filename)
-                log.info(message)
-            if "assembly" in cfg and os.path.isfile(result_contigs_paths_filename):
-                message = " * Paths in the assembly graph corresponding to the contigs are in " + \
-                          support.process_spaces(result_contigs_paths_filename)
-                log.info(message)
-            if "assembly" in cfg and os.path.isfile(result_scaffolds_paths_filename):
-                message = " * Paths in the assembly graph corresponding to the scaffolds are in " + \
-                          support.process_spaces(result_scaffolds_paths_filename)
-                log.info(message)
+            if options_storage.rna and "assembly" in cfg:
+                if os.path.isfile(result_transcripts_filename):
+                    message = " * Assembled transcripts are in " + support.process_spaces(result_transcripts_filename)
+                    log.info(message)
+                if os.path.isfile(result_transcripts_paths_filename):
+                    message = " * Paths in the assembly graph corresponding to the transcripts are in " + \
+                              support.process_spaces(result_transcripts_paths_filename)
+                    log.info(message)
+                for filtering_type in options_storage.filtering_types:
+                    result_filtered_transcripts_filename = os.path.join(cfg["common"].output_dir,
+                                                                        filtering_type + "_filtered_" +
+                                                                        options_storage.transcripts_name)
+                    if os.path.isfile(result_filtered_transcripts_filename):
+                        message = " * " + filtering_type.capitalize() + " filtered transcripts are in " + \
+                                  support.process_spaces(result_filtered_transcripts_filename)
+                        log.info(message)
+            elif "assembly" in cfg:
+                if os.path.isfile(result_scaffolds_filename):
+                    message = " * Assembled scaffolds are in " + support.process_spaces(result_scaffolds_filename)
+                    log.info(message)
+                if os.path.isfile(result_assembly_graph_filename):
+                    message = " * Assembly graph is in " + support.process_spaces(result_assembly_graph_filename)
+                    log.info(message)
+                if os.path.isfile(result_assembly_graph_filename_gfa):
+                    message = " * Assembly graph in GFA format is in " + support.process_spaces(result_assembly_graph_filename_gfa)
+                    log.info(message)
+                if os.path.isfile(result_contigs_paths_filename):
+                    message = " * Paths in the assembly graph corresponding to the contigs are in " + \
+                              support.process_spaces(result_contigs_paths_filename)
+                    log.info(message)
+                if os.path.isfile(result_scaffolds_paths_filename):
+                    message = " * Paths in the assembly graph corresponding to the scaffolds are in " + \
+                              support.process_spaces(result_scaffolds_paths_filename)
+                    log.info(message)
             #log.info("")
 
         #breaking scaffolds
@@ -898,13 +992,19 @@ def main(args):
             if options_storage.truseq_mode:
                 if not os.path.isfile(truseq_long_reads_file):
                     support.error("TEST FAILED: %s does not exist!" % truseq_long_reads_file)
+            elif options_storage.rna:
+                if not os.path.isfile(result_transcripts_filename):
+                    support.error("TEST FAILED: %s does not exist!" % result_transcripts_filename)
             else:
                 for result_filename in [result_contigs_filename, result_scaffolds_filename]:
                     if os.path.isfile(result_filename):
                         result_fasta = list(support.read_fasta(result_filename))
                         # correctness check: should be one contig of length 1000 bp
                         correct_number = 1
-                        correct_length = 1000
+                        if options_storage.plasmid:
+                            correct_length = 9667
+                        else:
+                            correct_length = 1000
                         if not len(result_fasta):
                             support.error("TEST FAILED: %s does not contain contigs!" % result_filename)
                         elif len(result_fasta) > correct_number:
