@@ -277,8 +277,14 @@ private:
         const double coverage_bound_;
         const size_t edge_limit_;
         mutable size_t edge_summary_length_;
+        const size_t edge_summary_length_limit_;
 
         void Find(EdgeId edge, std::set<EdgeId> &result) const {
+
+            if (edge_summary_length_ > edge_summary_length_limit_) {
+                return;
+            }
+
             if (result.size() > edge_limit_) {
                 return;
             }
@@ -307,12 +313,13 @@ private:
         }
 
     public:
-        CoverageBoundedDFS(const Graph &graph, double coverage_bound,
-                           size_t edge_limit = 10000)
+        CoverageBoundedDFS(const Graph &graph, double coverage_bound, size_t edge_summary_limit,
+                           size_t edge_limit = 500)
                 : graph_(graph),
                   coverage_bound_(coverage_bound),
                   edge_limit_(edge_limit),
-                  edge_summary_length_(0) {
+                  edge_summary_length_(0),
+                  edge_summary_length_limit_(edge_summary_limit) {
         }
 
         std::set<EdgeId> Find(VertexId v) const {
@@ -337,11 +344,15 @@ private:
     CoverageBoundedDFS dfs_helper;
 
 public:
-    HighCoverageComponentFinder(const Graph &graph, double max_coverage)
-    : AbstractNeighbourhoodFinder<Graph>(graph), coverage_bound_(max_coverage), dfs_helper(graph, max_coverage) {
+    HighCoverageComponentFinder(const Graph &graph,
+                                double max_coverage,
+                                size_t edge_sum_limit = std::numeric_limits<size_t>::max())
+            : AbstractNeighbourhoodFinder<Graph>(graph),
+              coverage_bound_(max_coverage),
+              dfs_helper(graph, max_coverage, edge_sum_limit) {
     }
 
-    GraphComponent<Graph> Find(typename Graph::VertexId v) const {
+    GraphComponent<Graph> Find(VertexId v) const {
         std::set<EdgeId> result = dfs_helper.Find(v);
         return GraphComponent<Graph>::FromEdges(this->graph(), result, false);
     }
@@ -388,8 +399,8 @@ private:
 
     set<VertexId> FindBorder(const GraphComponent<Graph>& component) const {
         set<VertexId> result;
-        insert_all(result, component.entrances());
-        insert_all(result, component.exits());
+        utils::insert_all(result, component.entrances());
+        utils::insert_all(result, component.exits());
         return result;
     }
 
@@ -784,7 +795,7 @@ shared_ptr<GraphSplitter<Graph>> ReliableSplitter(const Graph &graph,
                             size_t edge_length_bound = ReliableNeighbourhoodFinder<Graph>::DEFAULT_EDGE_LENGTH_BOUND,
                             size_t max_size = ReliableNeighbourhoodFinder<Graph>::DEFAULT_MAX_SIZE) {
     typedef typename Graph::VertexId VertexId;
-    shared_ptr<RelaxingIterator<VertexId>> inner_iterator = make_shared<CollectionIterator<set<VertexId>>>(graph.begin(), graph.end());
+    shared_ptr<RelaxingIterator<VertexId>> inner_iterator = make_shared<CollectionIterator<typename Graph::VertexContainer>>(graph.begin(), graph.end());
     shared_ptr<AbstractNeighbourhoodFinder<Graph>> nf = make_shared<ReliableNeighbourhoodFinder<Graph>>(graph, edge_length_bound, max_size);
     return make_shared<NeighbourhoodFindingSplitter<Graph>>(graph,
             inner_iterator, nf);
@@ -795,7 +806,7 @@ shared_ptr<GraphSplitter<Graph>> ConnectedSplitter(const Graph &graph,
                             size_t edge_length_bound = 1000000,
                             size_t max_size = 1000000) {
     typedef typename Graph::VertexId VertexId;
-    shared_ptr<RelaxingIterator<VertexId>> inner_iterator = make_shared<CollectionIterator<set<VertexId>>>(graph.begin(), graph.end());
+    shared_ptr<RelaxingIterator<VertexId>> inner_iterator = make_shared<CollectionIterator<typename Graph::VertexContainer>>(graph.begin(), graph.end());
     shared_ptr<AbstractNeighbourhoodFinder<Graph>> nf = make_shared<ReliableNeighbourhoodFinder<Graph>>(graph, edge_length_bound, max_size);
     return make_shared<NeighbourhoodFindingSplitter<Graph>>(graph,
             inner_iterator, nf);
@@ -822,7 +833,7 @@ shared_ptr<GraphSplitter<Graph>> LongEdgesExclusiveSplitter(
                 ReliableNeighbourhoodFinder<Graph>::DEFAULT_EDGE_LENGTH_BOUND) {
     typedef typename Graph::VertexId VertexId;
     shared_ptr<RelaxingIterator<VertexId>> inner_iterator = make_shared<
-            CollectionIterator<set<VertexId>>>(graph.begin(), graph.end());
+            CollectionIterator<typename Graph::VertexContainer>>(graph.begin(), graph.end());
     shared_ptr<AbstractNeighbourhoodFinder<Graph>> nf = make_shared<
             ShortEdgeComponentFinder<Graph>>(graph, bound);
     return make_shared<NeighbourhoodFindingSplitter<Graph>>(graph,
