@@ -11,12 +11,15 @@
 #include "utils/verify.hpp"
 #include "utils/logger/logger.hpp"
 #include "order_and_law.hpp"
+#include "utils/stl_utils.hpp"
+
+#include "adt/small_pod_vector.hpp"
+
 #include <boost/iterator/iterator_facade.hpp>
-#include "utils/simple_tools.hpp"
+#include <btree/safe_btree_set.h>
 
 namespace omnigraph {
 
-using std::vector;
 template<class DataMaster>
 class GraphCore;
 
@@ -92,7 +95,7 @@ private:
     typedef typename DataMaster::VertexData VertexData;
     typedef restricted::pure_pointer<PairedEdge<DataMaster>> EdgeId;
     typedef restricted::pure_pointer<PairedVertex<DataMaster>> VertexId;
-    typedef typename std::vector<EdgeId>::const_iterator edge_raw_iterator;
+    typedef typename adt::SmallPODVector<EdgeId>::const_iterator edge_raw_iterator;
 
     class conjugate_iterator : public boost::iterator_facade<conjugate_iterator,
             EdgeId, boost::forward_traversal_tag, EdgeId> {
@@ -137,7 +140,7 @@ private:
     friend class PairedElementManipulationHelper<VertexId>;
     friend class conjugate_iterator;
 
-    std::vector<EdgeId> outgoing_edges_;
+    adt::SmallPODVector<EdgeId> outgoing_edges_;
 
     VertexId conjugate_;
 
@@ -196,7 +199,7 @@ private:
     }
 
     const std::vector<EdgeId> OutgoingEdgesTo(VertexId v) const {
-        vector<EdgeId> result;
+        std::vector<EdgeId> result;
         for (auto it = outgoing_edges_.begin(); it != outgoing_edges_.end(); ++it) {
             if ((*it)->end() == v) {
                 result.push_back(*it);
@@ -232,13 +235,14 @@ public:
     typedef typename DataMasterT::EdgeData EdgeData;
     typedef restricted::pure_pointer<PairedEdge<DataMaster>> EdgeId;
     typedef restricted::pure_pointer<PairedVertex<DataMaster>> VertexId;
-    typedef typename std::set<VertexId>::const_iterator VertexIt;
+    typedef btree::safe_btree_set<VertexId> VertexContainer;
+    typedef typename VertexContainer::const_iterator VertexIt;
     typedef typename PairedVertex<DataMaster>::edge_const_iterator edge_const_iterator;
 
 private:
    restricted::LocalIdDistributor id_distributor_;
    DataMaster master_;
-   std::set<VertexId> vertices_;
+   VertexContainer vertices_;
 
    friend class ConstructionHelper<DataMaster>;
 public:
@@ -506,20 +510,20 @@ public:
         return edge->conjugate();
     }
 
-    size_t length(const EdgeId edge) const {
+    size_t length(EdgeId edge) const {
         return master_.length(data(edge));
     }
 
-    size_t length(const VertexId v) const {
+    size_t length(VertexId v) const {
         return master_.length(data(v));
     }
 
     //////////////////////shortcut methods
 
     std::vector<EdgeId> IncidentEdges(VertexId v) const {
-        vector<EdgeId> answer;
-        push_back_all(answer, IncomingEdges(v));
-        push_back_all(answer, OutgoingEdges(v));
+        std::vector<EdgeId> answer;
+        utils::push_back_all(answer, IncomingEdges(v));
+        utils::push_back_all(answer, OutgoingEdges(v));
         return answer;
     }
 
@@ -574,7 +578,7 @@ public:
 
     std::string str(const VertexId v) const {
 //      return master_.str(data(v));
-        return ToString(int_id(v));
+        return std::to_string(int_id(v));
     }
 
     std::string detailed_str(const VertexId v) const {
