@@ -222,14 +222,13 @@ public:
         return wc_ != nullptr;
     }
 
-    const WeightCounter& wc() const {
-        VERIFY(wc_);
-        return *wc_;
+    shared_ptr<WeightCounter> wc() const {
+        return wc_;
     }
 
 protected:
     bool HasIdealInfo(EdgeId e1, EdgeId e2, size_t dist) const {
-        return math::gr(wc_->lib().IdealPairedInfo(e1, e2, (int) dist), 0.);
+        return math::gr(wc_->PairedLibrary().IdealPairedInfo(e1, e2, (int) dist), 0.);
     }
 
     bool HasIdealInfo(const BidirectionalPath& p, EdgeId e, size_t gap) const {
@@ -286,6 +285,158 @@ public:
     }
 };
 
+
+class SimpleCoverageExtensionChooser: public ExtensionChooser {
+    const SSCoverageStorage& coverage_storage_;
+    //less than 1
+    double coverage_delta_;
+    //larger than 1
+    double inverted_coverage_delta_;
+
+    double min_upper_coverage_;
+
+public:
+    SimpleCoverageExtensionChooser(const SSCoverageStorage& coverage_storage, const Graph& g,
+                                   double coverage_delta, double min_upper_coverage = 0) :
+        ExtensionChooser(g), coverage_storage_(coverage_storage),
+        coverage_delta_(coverage_delta),
+        inverted_coverage_delta_(0),
+        min_upper_coverage_(min_upper_coverage) {
+        VERIFY(math::le(coverage_delta_, 1.0));
+        VERIFY(!math::eq(coverage_delta_, 0.0));
+        inverted_coverage_delta_ = 1.0 / coverage_delta_;
+    }
+
+    EdgeContainer Filter(const BidirectionalPath& path, const EdgeContainer& edges) const override {
+        if (edges.size() != 2)
+            return EdgeContainer();
+
+        size_t index = path.Size() - 1;
+        while (index > 0) {
+            if (g_.IncomingEdgeCount(g_.EdgeStart(path[index])) == 2)
+                break;
+            index--;
+        }
+
+        if (index == 0) {
+            return EdgeContainer();
+        }
+        DEBUG("Split found at " << index);
+        EdgeId path_edge_at_split = path[index - 1];
+
+        return Filter(path, edges, math::ls(coverage_storage_.GetCoverage(path_edge_at_split), coverage_storage_.GetCoverage(path_edge_at_split, true)));
+    }
+
+private:
+    EdgeContainer Filter(const BidirectionalPath& path, const EdgeContainer& edges, bool reverse) const {
+        DEBUG("COVERAGE extension chooser");
+        VERIFY(edges.size() == 2);
+        if (!IsEnoughCoverage(edges.front().e_, edges.back().e_, reverse)) {
+            DEBUG("Candidates are not covered enough: e1 = " << coverage_storage_.GetCoverage(edges.front().e_, reverse) <<
+                ", e2 = " << coverage_storage_.GetCoverage(edges.back().e_, reverse));
+            return EdgeContainer();
+        }
+
+        if (IsCoverageSimilar(edges.front().e_, edges.back().e_, reverse)) {
+            DEBUG("Candidates coverage is too similar: e1 = " << coverage_storage_.GetCoverage(edges.front().e_, reverse) <<
+                ", e2 = " << coverage_storage_.GetCoverage(edges.back().e_, reverse));
+            return EdgeContainer();
+        }
+
+        size_t index = path.Size() - 1;
+        while (index > 0) {
+            if (g_.IncomingEdgeCount(g_.EdgeStart(path[index])) == 2)
+                break;
+            index--;
+        }
+
+        EdgeContainer result;
+        if (index > 0) {
+            DEBUG("Split found at " << index);
+            EdgeId path_edge_at_split = path[index - 1];
+            EdgeId other_edge_at_split = GetOtherEdgeAtSplit(g_.EdgeEnd(path_edge_at_split), path_edge_at_split);
+            VERIFY(other_edge_at_split != EdgeId());
+
+            if (IsCoverageSimilar(path_edge_at_split, other_edge_at_split, reverse)) {
+                DEBUG("Path edge and alternative is too similar: path = " << coverage_storage_.GetCoverage(path_edge_at_split, reverse) <<
+                    ", other = " << coverage_storage_.GetCoverage(other_edge_at_split, reverse));
+
+                return EdgeContainer();
+            }
+            if (!IsEnoughCoverage(path_edge_at_split, other_edge_at_split, reverse)) {
+                DEBUG("Path edge and alternative  coverage is too low: path = " << coverage_storage_.GetCoverage(path_edge_at_split, reverse) <<
+                    ", other = " << coverage_storage_.GetCoverage(other_edge_at_split, reverse));
+
+                return EdgeContainer();
+            }
+
+            EdgeId candidate1 = edges.front().e_;
+            EdgeId candidate2 = edges.back().e_;
+
+            if (math::gr(coverage_storage_.GetCoverage(path_edge_at_split, reverse), coverage_storage_.GetCoverage(other_edge_at_split, reverse))) {
+                DEBUG("path coverage is high, edge " << g_.int_id(path_edge_at_split) << ", path cov = "
+                          << coverage_storage_.GetCoverage(path_edge_at_split, reverse) << ", other " << coverage_storage_.GetCoverage(other_edge_at_split, reverse));
+
+                result.emplace_back(math::gr(coverage_storage_.GetCoverage(candidate1, reverse), coverage_storage_.GetCoverage(candidate2, reverse)) ? candidate1 : candidate2, 0);
+            } else {
+                DEBUG("path coverage is low, edge " << g_.int_id(path_edge_at_split) << ", path cov = "
+                          << coverage_storage_.GetCoverage(path_edge_at_split, reverse) << ", other " << coverage_storage_.GetCoverage(other_edge_at_split, reverse));
+
+                result.emplace_back(math::ls(coverage_storage_.GetCoverage(candidate1, reverse), coverage_storage_.GetCoverage(candidate2, reverse)) ? candidate1 : candidate2, 0);
+            }
+
+            if (!IsCoverageSimilar(path_edge_at_split, result.front().e_, reverse)) {
+                DEBUG("Coverage is NOT similar: path = " << coverage_storage_.GetCoverage(path_edge_at_split, reverse) <<
+                    ", candidate = " << coverage_storage_.GetCoverage(result.front().e_, reverse))
+                result.clear();
+            }
+            else {
+                DEBUG("Coverage is similar: path = " << coverage_storage_.GetCoverage(path_edge_at_split, reverse) <<
+                    ", candidate = " << coverage_storage_.GetCoverage(result.front().e_, reverse))
+                DEBUG("Coverage extension chooser helped, adding " << g_.int_id(result.front().e_));
+            }
+        }
+
+        VERIFY(result.size() <= 1);
+        return result;
+    }
+
+    bool IsEnoughCoverage(EdgeId e1, EdgeId e2, bool reverse) const {
+        double cov1 = coverage_storage_.GetCoverage(e1, reverse);
+        double cov2 = coverage_storage_.GetCoverage(e2, reverse);
+        return math::ge(max(cov1, cov2), min_upper_coverage_) || math::eq(min(cov1, cov2), 0.0);
+    }
+
+    bool IsCoverageSimilar(EdgeId e1, EdgeId e2, bool reverse) const {
+        double cov1 = coverage_storage_.GetCoverage(e1, reverse);
+        double cov2 = coverage_storage_.GetCoverage(e2, reverse);
+
+        if (math::eq(cov2, 0.0) || math::eq(cov1, 0.0)) {
+            return false;
+        }
+
+        double diff = cov1 / cov2;
+        if (math::ls(diff, 1.0))
+            return math::gr(diff, coverage_delta_);
+        else
+            return math::ls(diff, inverted_coverage_delta_);
+    }
+
+    EdgeId GetOtherEdgeAtSplit(VertexId split, EdgeId e) const {
+        VERIFY(g_.IncomingEdgeCount(split) == 2);
+        for (auto other : g_.IncomingEdges(split)) {
+            if (e != other)
+                return other;
+        }
+        return EdgeId();
+    }
+
+    DECL_LOGGER("SimpleCoverageExtensionChooser");
+
+};
+
+
+
 class ExcludingExtensionChooser: public ExtensionChooser {
     PathAnalyzer analyzer_;
     double prior_coeff_;
@@ -346,7 +497,7 @@ public:
             return edges;
         }
         std::set<size_t> to_exclude;
-        path.Print();
+        path.PrintDEBUG();
         EdgeContainer result = edges;
         ExcludeEdges(path, result, to_exclude);
         result = FindFilteredEdges(path, result, to_exclude);
@@ -509,8 +660,6 @@ public:
 };
 
 class ScaffoldingExtensionChooser : public ExtensionChooser {
-
-protected:
     typedef ExtensionChooser base;
     double raw_weight_threshold_;
     double cl_weight_threshold_;
@@ -539,7 +688,7 @@ protected:
 
     void GetDistances(EdgeId e1, EdgeId e2, std::vector<int>& dist,
             std::vector<double>& w) const {
-        wc_->lib().CountDistances(e1, e2, dist, w);
+        wc_->PairedLibrary().CountDistances(e1, e2, dist, w);
     }
 
     void CountAvrgDists(const BidirectionalPath& path, EdgeId e, std::vector<pair<int, double>> & histogram) const {
@@ -580,7 +729,7 @@ protected:
 
     set<EdgeId> FindCandidates(const BidirectionalPath& path) const {
         set<EdgeId> jumping_edges;
-        const auto& lib = wc_->lib();
+        const auto& lib = wc_->PairedLibrary();
         //todo lib (and FindJumpEdges) knows its var so it can be counted there
         int is_scatter = int(math::round(lib.GetIsVar() * is_scatter_coeff_));
         for (int i = (int) path.Size() - 1; i >= 0 && path.LengthAt(i) - g_.length(path.At(i)) <= lib.GetISMax(); --i) {
@@ -630,7 +779,6 @@ inline bool EdgeWithWeightCompareReverse(const pair<EdgeId, double>& p1,
 }
 
 class LongReadsUniqueEdgeAnalyzer {
-private:
     DECL_LOGGER("LongReadsUniqueEdgeAnalyzer")
 public:
     LongReadsUniqueEdgeAnalyzer(const Graph& g, const GraphCoverageMap& cov_map,
@@ -812,51 +960,51 @@ private:
     bool uneven_depth_;
 };
 
-class SimpleScaffolding {
-public:
-    SimpleScaffolding(const Graph& g) : g_(g) {}
-
-    BidirectionalPath FindMaxCommonPath(const vector<BidirectionalPath*>& paths,
-                                        size_t max_diff_len) const {
-        BidirectionalPath max_end(g_);
-        for (auto it1 = paths.begin(); it1 != paths.end(); ++it1) {
-            BidirectionalPath* p1 = *it1;
-            for (size_t i = 0; i < p1->Size(); ++i) {
-                if (p1->Length() - p1->LengthAt(i) > max_diff_len) {
-                    break;
-                }
-                bool contain_all = true;
-                for (size_t i1 = i + 1; i1 <= p1->Size() && contain_all; ++i1) {
-                    BidirectionalPath subpath = p1->SubPath(i, i1);
-                    for (auto it2 = paths.begin();  it2 != paths.end() && contain_all; ++it2) {
-                        BidirectionalPath* p2 = *it2;
-                        vector<size_t> positions2 = p2->FindAll(subpath.At(0));
-                        bool contain = false;
-                        for (size_t ipos2 = 0; ipos2 < positions2.size(); ++ipos2) {
-                            size_t pos2 = positions2[ipos2];
-                            if (p2->Length() - p2->LengthAt(pos2) <= max_diff_len
-                                    && EqualEnds(subpath, 0, *p2, pos2, false)) {
-                                contain = true;
-                                break;
-                            }
-                        }
-                        if (!contain) {
-                            contain_all = false;
-                        }
-                    }
-                    if (contain_all && (i1 - i) >= max_end.Size()) {
-                        max_end.Clear();
-                        max_end.PushBack(subpath);
-                    }
-                }
-            }
-        }
-        return max_end;
-    }
-
-private:
-    const Graph& g_;
-};
+//class SimpleScaffolding {
+//public:
+//    SimpleScaffolding(const Graph& g) : g_(g) {}
+//
+//    BidirectionalPath FindMaxCommonPath(const vector<BidirectionalPath*>& paths,
+//                                        size_t max_diff_len) const {
+//        BidirectionalPath max_end(g_);
+//        for (auto it1 = paths.begin(); it1 != paths.end(); ++it1) {
+//            BidirectionalPath* p1 = *it1;
+//            for (size_t i = 0; i < p1->Size(); ++i) {
+//                if (p1->Length() - p1->LengthAt(i) > max_diff_len) {
+//                    break;
+//                }
+//                bool contain_all = true;
+//                for (size_t i1 = i + 1; i1 <= p1->Size() && contain_all; ++i1) {
+//                    BidirectionalPath subpath = p1->SubPath(i, i1);
+//                    for (auto it2 = paths.begin();  it2 != paths.end() && contain_all; ++it2) {
+//                        BidirectionalPath* p2 = *it2;
+//                        vector<size_t> positions2 = p2->FindAll(subpath.At(0));
+//                        bool contain = false;
+//                        for (size_t ipos2 = 0; ipos2 < positions2.size(); ++ipos2) {
+//                            size_t pos2 = positions2[ipos2];
+//                            if (p2->Length() - p2->LengthAt(pos2) <= max_diff_len
+//                                    && EqualEnds(subpath, 0, *p2, pos2, false)) {
+//                                contain = true;
+//                                break;
+//                            }
+//                        }
+//                        if (!contain) {
+//                            contain_all = false;
+//                        }
+//                    }
+//                    if (contain_all && (i1 - i) >= max_end.Size()) {
+//                        max_end.Clear();
+//                        max_end.PushBack(subpath);
+//                    }
+//                }
+//            }
+//        }
+//        return max_end;
+//    }
+//
+//private:
+//    const Graph& g_;
+//};
 
 class LongReadsExtensionChooser : public ExtensionChooser {
 public:
@@ -875,8 +1023,7 @@ public:
               cov_map_(read_paths_cov_map),
               unique_edge_analyzer_(g, cov_map_, filtering_threshold,
                                     unique_edge_priority_threshold,
-                                    max_repeat_length, uneven_depth),
-              simple_scaffolding_(g)
+                                    max_repeat_length, uneven_depth)
     {
     }
 
@@ -889,13 +1036,12 @@ public:
         if (edges.empty()) {
             return edges;
         }DEBUG("We in Filter of LongReadsExtensionChooser");
-        path.Print();
+        path.PrintDEBUG();
         map<EdgeId, double> weights_cands;
         for (auto it = edges.begin(); it != edges.end(); ++it) {
             weights_cands.insert(make_pair(it->e_, 0.0));
         }
         set<EdgeId> filtered_cands;
-        map<EdgeId, BidirectionalPathSet > support_paths_ends;
         auto support_paths = cov_map_.GetCoveringPaths(path.Back());
         DEBUG("Found " << support_paths.size() << " covering paths!!!");
         for (auto it = support_paths.begin(); it != support_paths.end(); ++it) {
@@ -912,10 +1058,6 @@ public:
                         EdgeId next = (*it)->At(positions[i] + 1);
                         weights_cands[next] += (*it)->GetWeight();
                         filtered_cands.insert(next);
-                        if (support_paths_ends.count(next) == 0){
-                            support_paths_ends[next] = BidirectionalPathSet();
-                        }
-                        support_paths_ends[next].insert(new BidirectionalPath((*it)->SubPath(positions[i] + 1)));
                     }
                 }
             }
@@ -974,7 +1116,6 @@ private:
     size_t min_significant_overlap_;
     const GraphCoverageMap& cov_map_;
     LongReadsUniqueEdgeAnalyzer unique_edge_analyzer_;
-    SimpleScaffolding simple_scaffolding_;
 
     DECL_LOGGER("LongReadsExtensionChooser");
 };
