@@ -31,13 +31,14 @@ shared_ptr<SimpleExtender> ExtendersGenerator::MakeLongReadsExtender(size_t lib_
         resolvable_repeat_length_bound = std::max(resolvable_repeat_length_bound, lib.data().read_length);
     }
     INFO("resolvable_repeat_length_bound set to " << resolvable_repeat_length_bound);
-
+    bool investigate_short_loop = lib.is_contig_lib() || lib.is_long_read_lib() || support_.UseCoverageResolverForSingleReads(lib.type());
 
     auto long_read_ec = MakeLongReadsExtensionChooser(lib_index, read_paths_cov_map);
     return make_shared<SimpleExtender>(gp_, cover_map_,
+                                       used_unique_storage_,
                                        long_read_ec,
                                        resolvable_repeat_length_bound,
-                                       true, /* investigate short loops */
+                                       investigate_short_loop, /* investigate short loops */
                                        support_.UseCoverageResolverForSingleReads(lib.type()));
 }
 
@@ -58,35 +59,36 @@ shared_ptr<SimpleExtender> ExtendersGenerator::MakeLongEdgePEExtender(size_t lib
                                               opts.priority_coeff);
 
     return make_shared<SimpleExtender>(gp_, cover_map_,
+                                       used_unique_storage_,
                                        extension,
                                        paired_lib->GetISMax(),
                                        investigate_loops,
-                                       false /*use short loop coverage resolver*/);
+                                       false /*use short loop coverage resolver*/,
+                                       opts.weight_threshold);
 }
 
-shared_ptr<GapJoiner> ExtendersGenerator::MakeGapJoiners(double is_variation) const {
+shared_ptr<GapAnalyzer> ExtendersGenerator::MakeGapAnalyzer(double is_variation) const {
     const auto &pset = params_.pset;
 
-    vector<shared_ptr<GapJoiner>> joiners;
+    vector<shared_ptr<GapAnalyzer>> joiners;
     if (params_.pset.scaffolder_options.use_la_gap_joiner)
-        joiners.push_back(std::make_shared<LAGapJoiner>(gp_.g, pset.scaffolder_options.min_overlap_length,
+        joiners.push_back(std::make_shared<LAGapAnalyzer>(gp_.g, pset.scaffolder_options.min_overlap_length,
                                                         pset.scaffolder_options.flank_multiplication_coefficient,
                                                         pset.scaffolder_options.flank_addition_coefficient));
 
 
-    joiners.push_back(std::make_shared<HammingGapJoiner>(gp_.g,
+    joiners.push_back(std::make_shared<HammingGapAnalyzer>(gp_.g,
                                                          pset.scaffolder_options.min_gap_score,
                                                          pset.scaffolder_options.short_overlap,
                                                          (int) pset.scaffolder_options.basic_overlap_coeff
                                                              * dataset_info_.RL()));
 
-    return std::make_shared<CompositeGapJoiner>(gp_.g,
+    //todo introduce explicit must_overlap_coeff and rename max_can_overlap -> can_overlap_coeff
+    return std::make_shared<CompositeGapAnalyzer>(gp_.g,
                                                 joiners,
-                                                size_t(pset.scaffolder_options.max_can_overlap
-                                                           * (double) gp_.g.k()), /* may overlap threshold */
-                                                int(math::round(double(gp_.g.k())
-                                                                    - pset.scaffolder_options.var_coeff
-                                                                        * is_variation)),  /* must overlap threshold */
+                                                size_t(math::round(pset.scaffolder_options.max_can_overlap
+                                                           * is_variation)), /* may overlap threshold */
+                                                int(math::round(-pset.scaffolder_options.var_coeff * is_variation)), /* must overlap threshold */
                                                 pset.scaffolder_options.artificial_gap);
 
 }
@@ -103,8 +105,9 @@ shared_ptr<PathExtender> ExtendersGenerator::MakeScaffoldingExtender(size_t lib_
                                                                        pset.scaffolder_options.cl_threshold,
                                                                        pset.scaffolder_options.var_coeff);
 
-    return make_shared<ScaffoldingPathExtender>(gp_, cover_map_, scaff_chooser,
-                                                MakeGapJoiners(paired_lib->GetIsVar()),
+    return make_shared<ScaffoldingPathExtender>(gp_, cover_map_,
+                                                used_unique_storage_, scaff_chooser,
+                                                MakeGapAnalyzer(paired_lib->GetIsVar()),
                                                 paired_lib->GetISMax(),
                                                 false, /* investigate short loops */
                                                 params_.avoid_rc_connections);
@@ -130,17 +133,17 @@ shared_ptr<PathExtender> ExtendersGenerator::MakeRNAScaffoldingExtender(size_t l
 
     VERIFY(pset.scaffolder_options.min_overlap_for_rna_scaffolding.is_initialized());
     return make_shared<RNAScaffoldingPathExtender>(gp_, cover_map_,
+                                                   used_unique_storage_,
                                                    scaff_chooser,
                                                    scaff_chooser2,
-                                                   MakeGapJoiners(paired_lib->GetIsVar()),
+                                                   MakeGapAnalyzer(paired_lib->GetIsVar()),
                                                    paired_lib->GetISMax(),
                                                    false  /* investigate short loops */,
                                                    *pset.scaffolder_options.min_overlap_for_rna_scaffolding);
 }
 
-shared_ptr<PathExtender> ExtendersGenerator::MakeMatePairScaffoldingExtender(
-    size_t lib_index,
-    const ScaffoldingUniqueEdgeStorage &storage) const {
+shared_ptr<PathExtender> ExtendersGenerator::MakeMatePairScaffoldingExtender(size_t lib_index,
+                                                                             const ScaffoldingUniqueEdgeStorage &storage) const {
 
     const auto &lib = dataset_info_.reads[lib_index];
     const auto &pset = params_.pset;
@@ -173,8 +176,9 @@ shared_ptr<PathExtender> ExtendersGenerator::MakeMatePairScaffoldingExtender(
                                                                     <= params_.pset.scaffolding2015.graph_connectivity_max_edges);
 
     return make_shared<ScaffoldingPathExtender>(gp_, cover_map_,
+                                                used_unique_storage_,
                                                 scaff_chooser,
-                                                MakeGapJoiners(paired_lib->GetIsVar()),
+                                                MakeGapAnalyzer(paired_lib->GetIsVar()),
                                                 paired_lib->GetISMax(),
                                                 false, /* investigate short loops */
                                                 params_.avoid_rc_connections,
@@ -204,10 +208,11 @@ shared_ptr<SimpleExtender> ExtendersGenerator::MakeCoordCoverageExtender(size_t
 
     auto chooser = make_shared<JointExtensionChooser>(gp_.g, permissive_pi_chooser, coord_cov_chooser);
 
-    return make_shared<SimpleExtender>(gp_, cover_map_, chooser,
+    return make_shared<SimpleExtender>(gp_, cover_map_, used_unique_storage_, chooser,
                                        -1ul /* insert size is needed only for loop detection, which is not needed in this case */,
                                        false, /* investigate short loops */
-                                       false /*use short loop coverage resolver*/);
+                                       false /*use short loop coverage resolver*/,
+                                       params_.pset.extension_options.weight_threshold);
 }
 
 shared_ptr<SimpleExtender> ExtendersGenerator::MakeRNAExtender(size_t lib_index, bool investigate_loops) const {
@@ -229,12 +234,31 @@ shared_ptr<SimpleExtender> ExtendersGenerator::MakeRNAExtender(size_t lib_index,
                                          opts.priority_coeff);
 
     return make_shared<MultiExtender>(gp_, cover_map_,
+                                      used_unique_storage_,
                                       extension,
                                       paired_lib->GetISMax(),
                                       investigate_loops,
-                                      false /*use short loop coverage resolver*/);
+                                      false /*use short loop coverage resolver*/,
+                                      opts.weight_threshold);
 }
 
+
+shared_ptr<SimpleExtender> ExtendersGenerator::MakeSimpleCoverageExtender(size_t lib_index) const {
+
+    auto extension =
+        make_shared<SimpleCoverageExtensionChooser>(gp_.ss_coverage[lib_index], gp_.g,
+                                                    params_.pset.simple_coverage_resolver.coverage_delta,
+                                                    params_.pset.simple_coverage_resolver.min_upper_coverage);
+
+    return make_shared<SimpleExtender>(gp_, cover_map_,
+                                       used_unique_storage_,
+                                       extension,
+                                       1000, /*insert size for cycle detection*/
+                                       false /*investigate short loops*/,
+                                       false /*use short loop coverage resolver*/);
+}
+
+
 shared_ptr<SimpleExtender> ExtendersGenerator::MakePEExtender(size_t lib_index, bool investigate_loops) const {
     const auto &lib = dataset_info_.reads[lib_index];
     shared_ptr<PairedInfoLibrary> paired_lib = MakeNewLib(gp_.g, lib, gp_.clustered_indices[lib_index]);
@@ -261,12 +285,26 @@ shared_ptr<SimpleExtender> ExtendersGenerator::MakePEExtender(size_t lib_index,
                                                          opts.priority_coeff);
 
     return make_shared<SimpleExtender>(gp_, cover_map_,
+                                       used_unique_storage_,
                                        extension_chooser,
                                        paired_lib->GetISMax(),
                                        investigate_loops,
-                                       false /*use short loop coverage resolver*/);
+                                       false /*use short loop coverage resolver*/,
+                                       opts.weight_threshold);
 }
 
+//FIXME do we need ExtenderTriplets story here?
+//FIXME integrate with MakeBasicExtenders
+Extenders ExtendersGenerator::MakePEExtenders() const {
+    Extenders result;
+    for (size_t lib_index = 0; lib_index < dataset_info_.reads.lib_count(); ++lib_index) {
+        const auto &lib = dataset_info_.reads[lib_index];
+        if (support_.IsForPEExtender(lib)) {
+            result.push_back(MakePEExtender(lib_index, false));
+        }
+    }
+    return result;
+}
 
 void ExtendersGenerator::PrintExtenders(const Extenders &extenders) const {
     DEBUG("Extenders in vector:");
@@ -274,12 +312,12 @@ void ExtendersGenerator::PrintExtenders(const Extenders &extenders) const {
         //TODO: use polymorphism instead of RTTI
         auto ext_ptr = extender.get();
         DEBUG("Extender #i" << typeid(*ext_ptr).name());
-        if (instanceof<SimpleExtender>(ext_ptr)) {
+        if (utils::instanceof<SimpleExtender>(ext_ptr)) {
             auto ec = ((SimpleExtender *) ext_ptr)->GetExtensionChooser();
             auto ec_ptr = ec.get();
             DEBUG("    Extender #i" << typeid(*ec_ptr).name());
         }
-        else if (instanceof<ScaffoldingPathExtender>(ext_ptr)) {
+        else if (utils::instanceof<ScaffoldingPathExtender>(ext_ptr)) {
             auto ec = ((ScaffoldingPathExtender *) ext_ptr)->GetExtensionChooser();
             auto ec_ptr = ec.get();
             DEBUG("    Extender #i" << typeid(*ec_ptr).name());
@@ -287,6 +325,16 @@ void ExtendersGenerator::PrintExtenders(const Extenders &extenders) const {
     }
 }
 
+Extenders ExtendersGenerator::MakeMPExtenders() const {
+    Extenders extenders = MakeMPExtenders(unique_data_.main_unique_storage_);
+    INFO("Using " << extenders.size() << " mate-pair " << support_.LibStr(extenders.size()));
+
+    for (const auto& unique_storage : unique_data_.unique_storages_) {
+        utils::push_back_all(extenders, MakeMPExtenders(unique_storage));
+    }
+    return extenders;
+}
+
 Extenders ExtendersGenerator::MakeMPExtenders(const ScaffoldingUniqueEdgeStorage &storage) const {
     ExtenderTriplets result;
 
@@ -294,7 +342,8 @@ Extenders ExtendersGenerator::MakeMPExtenders(const ScaffoldingUniqueEdgeStorage
         const auto &lib = dataset_info_.reads[lib_index];
 
         if (lib.is_mate_pair()) {
-            result.emplace_back(lib.type(), lib_index, MakeMatePairScaffoldingExtender(lib_index, storage));
+            result.emplace_back(lib.type(), lib_index,
+                                MakeMatePairScaffoldingExtender(lib_index, storage));
         }
     }
     std::stable_sort(result.begin(), result.end());
@@ -302,8 +351,7 @@ Extenders ExtendersGenerator::MakeMPExtenders(const ScaffoldingUniqueEdgeStorage
     return ExtractExtenders(result);
 }
 
-Extenders ExtendersGenerator::MakePBScaffoldingExtenders(const ScaffoldingUniqueEdgeStorage &unique_storage_pb,
-                                                         const vector<shared_ptr<GraphCoverageMap>> &long_reads_cov_map) const {
+Extenders ExtendersGenerator::MakePBScaffoldingExtenders() const {
     const auto &pset = params_.pset;
     ExtenderTriplets result;
 
@@ -312,20 +360,22 @@ Extenders ExtendersGenerator::MakePBScaffoldingExtenders(const ScaffoldingUnique
             INFO("Creating scaffolding extender for lib " << lib_index);
             shared_ptr<ConnectionCondition> condition = make_shared<LongReadsLibConnectionCondition>(gp_.g,
                                                                                                      lib_index, 2,
-                                                                                                     *long_reads_cov_map[lib_index]);
+                                                                                                     unique_data_.long_reads_cov_map_[lib_index]);
             auto scaff_chooser = std::make_shared<ExtensionChooser2015>(gp_.g,
                                                                         nullptr,
                                                                         condition,
-                                                                        unique_storage_pb,
+                                                                        unique_data_.unique_pb_storage_,
                                                                         pset.scaffolder_options.cl_threshold,
                                                                         pset.scaffolder_options.var_coeff,
                                                                         pset.scaffolding2015.relative_weight_cutoff);
 
             result.emplace_back(dataset_info_.reads[lib_index].type(),
                                 lib_index,
+                                //FIXME are utilized constants reasonable?
                                 make_shared<ScaffoldingPathExtender>(gp_, cover_map_,
+                                                                     used_unique_storage_,
                                                                      scaff_chooser,
-                                                                     MakeGapJoiners(1000), /* "IS vatiation" */
+                                                                     MakeGapAnalyzer(1000), /* "IS variation" */
                                                                      10000, /* insert size */
                                                                      false, /* investigate short loops */
                                                                      params_.avoid_rc_connections,
@@ -349,8 +399,7 @@ Extenders ExtendersGenerator::MakeCoverageExtenders() const {
     return result;
 }
 
-Extenders ExtendersGenerator::MakeBasicExtenders(const ScaffoldingUniqueEdgeStorage &storage,
-                                                 const vector<shared_ptr<GraphCoverageMap>> &long_reads_cov_map) const {
+Extenders ExtendersGenerator::MakeBasicExtenders() const {
     ExtenderTriplets basic_extenders;
     ExtenderTriplets loop_resolving_extenders;
     ExtenderTriplets scaffolding_extenders;
@@ -366,7 +415,9 @@ Extenders ExtendersGenerator::MakeBasicExtenders(const ScaffoldingUniqueEdgeStor
 
         //TODO: scaff2015 does not need any single read libs?
         if (support_.IsForSingleReadExtender(lib)) {
-            basic_extenders.emplace_back(lib.type(), lib_index, MakeLongReadsExtender(lib_index, *long_reads_cov_map[lib_index]));
+            basic_extenders.emplace_back(lib.type(), lib_index,
+                                         MakeLongReadsExtender(lib_index,
+                                                               unique_data_.long_reads_cov_map_[lib_index]));
             ++single_read_libs;
         }
         if (support_.IsForPEExtender(lib)) {
@@ -376,12 +427,16 @@ Extenders ExtendersGenerator::MakeBasicExtenders(const ScaffoldingUniqueEdgeStor
                     basic_extenders.emplace_back(lib.type(), lib_index, MakeLongEdgePEExtender(lib_index, false));
                 } else if (pset.multi_path_extend) {
                     basic_extenders.emplace_back(lib.type(), lib_index, MakePEExtender(lib_index, false));
+                    if (pset.simple_coverage_resolver.enabled)
+                        basic_extenders.emplace_back(lib.type(), lib_index, MakeSimpleCoverageExtender(lib_index));
                     basic_extenders.emplace_back(lib.type(), lib_index, MakeRNAExtender(lib_index, false));
                 } else {
                     basic_extenders.emplace_back(lib.type(), lib_index, MakePEExtender(lib_index, false));
                 }
             } else if (pset.sm == sm_2015) {
-                basic_extenders.emplace_back(lib.type(), lib_index, MakeMatePairScaffoldingExtender(lib_index, storage));
+                basic_extenders.emplace_back(lib.type(), lib_index,
+                                             MakeMatePairScaffoldingExtender(lib_index,
+                                                                             unique_data_.main_unique_storage_));
             }
         }
         //TODO logic is very cryptic!
@@ -397,7 +452,9 @@ Extenders ExtendersGenerator::MakeBasicExtenders(const ScaffoldingUniqueEdgeStor
             } else {
                 scaffolding_extenders.emplace_back(lib.type(), lib_index, MakeScaffoldingExtender(lib_index));
                 if (pset.sm == sm_combined) {
-                    scaffolding_extenders.emplace_back(lib.type(), lib_index, MakeMatePairScaffoldingExtender(lib_index, storage));
+                    scaffolding_extenders.emplace_back(lib.type(), lib_index,
+                                                       MakeMatePairScaffoldingExtender(lib_index,
+                                                                                       unique_data_.main_unique_storage_));
                 }
             }
         }
@@ -408,9 +465,9 @@ Extenders ExtendersGenerator::MakeBasicExtenders(const ScaffoldingUniqueEdgeStor
     std::stable_sort(loop_resolving_extenders.begin(), loop_resolving_extenders.end());
 
     Extenders result;
-    push_back_all(result, ExtractExtenders(basic_extenders));
-    push_back_all(result, ExtractExtenders(scaffolding_extenders));
-    push_back_all(result, ExtractExtenders(loop_resolving_extenders));
+    utils::push_back_all(result, ExtractExtenders(basic_extenders));
+    utils::push_back_all(result, ExtractExtenders(scaffolding_extenders));
+    utils::push_back_all(result, ExtractExtenders(loop_resolving_extenders));
 
     INFO("Using " << pe_libs << " paired-end " << support_.LibStr(pe_libs));
     INFO("Using " << scf_pe_libs << " paired-end scaffolding " << support_.LibStr(scf_pe_libs));
