@@ -6,6 +6,7 @@
 
 #include "modules/path_extend/path_visualizer.hpp"
 #include "modules/path_extend/loop_traverser.hpp"
+#include "modules/path_extend/path_extender.hpp"
 #include "modules/alignment/long_read_storage.hpp"
 #include "modules/path_extend/scaffolder2015/extension_chooser2015.hpp"
 #include "modules/path_extend/scaffolder2015/scaffold_graph_visualizer.hpp"
@@ -20,7 +21,6 @@ namespace path_extend {
 using namespace debruijn_graph;
 using namespace std;
 
-
 vector<shared_ptr<ConnectionCondition>>
     PathExtendLauncher::ConstructPairedConnectionConditions(const ScaffoldingUniqueEdgeStorage& edge_storage) const {
 
@@ -39,7 +39,7 @@ vector<shared_ptr<ConnectionCondition>>
                 INFO("Unusable for scaffold graph paired lib #" << lib_index);
                 continue;
             }
-            conditions.push_back(make_shared<ScaffoldGraphPairedConnectionCondition>(gp_.g, edge_storage.GetSet(),
+            conditions.push_back(make_shared<ScaffoldGraphPairedConnectionCondition>(gp_.g, edge_storage.unique_edges(),
                                                                                      paired_lib, lib_index,
                                                                                      params.always_add,
                                                                                      params.never_add,
@@ -55,7 +55,7 @@ shared_ptr<scaffold_graph::ScaffoldGraph> PathExtendLauncher::ConstructScaffoldG
     const pe_config::ParamSetT::ScaffoldGraphParamsT &params = params_.pset.scaffold_graph_params;
 
     INFO("Constructing connections");
-    LengthLowerBound edge_condition(gp_.g, edge_storage.GetMinLength());
+    LengthLowerBound edge_condition(gp_.g, edge_storage.min_length());
 
     vector<shared_ptr<ConnectionCondition>> conditions =
         ConstructPairedConnectionConditions(edge_storage);
@@ -68,9 +68,9 @@ shared_ptr<scaffold_graph::ScaffoldGraph> PathExtendLauncher::ConstructScaffoldG
 
     INFO("Total conditions " << conditions.size());
 
-    INFO("Constructing scaffold graph from set of size " << edge_storage.GetSet().size());
+    INFO("Constructing scaffold graph from set of size " << edge_storage.unique_edges().size());
 
-    DefaultScaffoldGraphConstructor constructor(gp_.g, edge_storage.GetSet(), conditions, edge_condition);
+    DefaultScaffoldGraphConstructor constructor(gp_.g, edge_storage.unique_edges(), conditions, edge_condition);
     auto scaffold_graph = constructor.Construct();
 
     INFO("Scaffold graph contains " << scaffold_graph->VertexCount() << " vertices and " << scaffold_graph->EdgeCount()
@@ -84,27 +84,12 @@ void PathExtendLauncher::PrintScaffoldGraph(const scaffold_graph::ScaffoldGraph
                                             const string &filename) const {
     using namespace scaffold_graph;
 
-    INFO("Constructing reference labels");
-    map<debruijn_graph::EdgeId, string> edge_labels;
-    size_t count = 0;
-    for (const auto &edge_coord_pair: genome_checker.ConstructEdgeOrder()) {
-        if (edge_labels.find(edge_coord_pair.first) == edge_labels.end()) {
-            edge_labels[edge_coord_pair.first] = "";
-        }
-        edge_labels[edge_coord_pair.first] += "order: " + ToString(count) +
-            "\n mapped range: " + ToString(edge_coord_pair.second.mapped_range.start_pos) + " : "
-            + ToString(edge_coord_pair.second.mapped_range.end_pos) +
-            "\n init range: " + ToString(edge_coord_pair.second.initial_range.start_pos) + " : "
-            + ToString(edge_coord_pair.second.initial_range.end_pos) + "\n";
-        ++count;
-    }
-
     auto vertex_colorer = make_shared<ScaffoldVertexSetColorer>(main_edge_set);
     auto edge_colorer = make_shared<ScaffoldEdgeColorer>();
     graph_colorer::CompositeGraphColorer<ScaffoldGraph> colorer(vertex_colorer, edge_colorer);
 
     INFO("Visualizing scaffold graph");
-    ScaffoldGraphVisualizer singleVisualizer(scaffold_graph, edge_labels);
+    ScaffoldGraphVisualizer singleVisualizer(scaffold_graph, genome_checker.EdgeLabels());
     std::ofstream single_dot;
     single_dot.open((filename + "_single.dot").c_str());
     singleVisualizer.Visualize(single_dot, colorer);
@@ -122,13 +107,17 @@ void PathExtendLauncher::MakeAndOutputScaffoldGraph() const {
     //Scaffold graph
     shared_ptr<scaffold_graph::ScaffoldGraph> scaffold_graph;
     if (params_.pset.scaffold_graph_params.construct) {
-        debruijn_graph::GenomeConsistenceChecker genome_checker(gp_, unique_data_.main_unique_storage_,
+        debruijn_graph::GenomeConsistenceChecker genome_checker(gp_,
                                                                 params_.pset.genome_consistency_checker.max_gap,
-                                                                params_.pset.genome_consistency_checker.relative_max_gap);
+                                                                params_.pset.genome_consistency_checker.relative_max_gap,
+                                                                unique_data_.main_unique_storage_.min_length(),
+                                                                unique_data_.main_unique_storage_,
+                                                                unique_data_.long_reads_cov_map_,
+                                                                dataset_info_.reads);
         scaffold_graph = ConstructScaffoldGraph(unique_data_.main_unique_storage_);
         if (params_.pset.scaffold_graph_params.output) {
             PrintScaffoldGraph(*scaffold_graph,
-                               unique_data_.main_unique_storage_.GetSet(),
+                               unique_data_.main_unique_storage_.unique_edges(),
                                genome_checker,
                                params_.etc_dir + "scaffold_graph");
         }
@@ -138,26 +127,38 @@ void PathExtendLauncher::MakeAndOutputScaffoldGraph() const {
 void PathExtendLauncher::CountMisassembliesWithReference(const PathContainer &paths) const {
     if (gp_.genome.size() == 0)
         return;
-
-    debruijn_graph::GenomeConsistenceChecker genome_checker(gp_, unique_data_.main_unique_storage_,
+    bool use_main_storage = params_.pset.genome_consistency_checker.use_main_storage;
+    size_t unresolvable_gap = unique_data_.main_unique_storage_.min_length();
+    ScaffoldingUniqueEdgeStorage tmp_storage;
+    if (!use_main_storage) {
+        unresolvable_gap = params_.pset.genome_consistency_checker.unresolvable_jump;
+        ScaffoldingUniqueEdgeAnalyzer tmp_analyzer(gp_, params_.pset.genome_consistency_checker.unique_length, unique_data_.unique_variation_);
+        tmp_analyzer.FillUniqueEdgeStorage(tmp_storage);
+    }
+    debruijn_graph::GenomeConsistenceChecker genome_checker(gp_,
                                                             params_.pset.genome_consistency_checker.max_gap,
-                                                            params_.pset.genome_consistency_checker.relative_max_gap);
+                                                            params_.pset.genome_consistency_checker.relative_max_gap,
+                                                            unresolvable_gap,
+                                                            use_main_storage ? unique_data_.main_unique_storage_ : tmp_storage,
+                                                            unique_data_.long_reads_cov_map_,
+                                                            dataset_info_.reads);
 
     size_t total_mis = 0, gap_mis = 0;
-    genome_checker.SpellGenome();
     for (auto iter = paths.begin(); iter != paths.end(); ++iter) {
         BidirectionalPath *path = iter.get();
         auto map_res = genome_checker.CountMisassemblies(*path);
         if (map_res.misassemblies > 0) {
             INFO ("there are " << map_res.misassemblies << " misassemblies in path: ");
-            path->PrintInfo();
+            path->PrintINFO();
             total_mis += map_res.misassemblies;
         }
         if (map_res.wrong_gap_size > 0) {
-            INFO ("there are " << map_res.wrong_gap_size << " wrong gaps in path: ");
-            path->PrintInfo();
+            INFO ("there are " << map_res.wrong_gap_size << " wrong gaps in path. ");
+            path->PrintDEBUG();
             gap_mis += map_res.wrong_gap_size;
         }
+        genome_checker.CheckPathEnd(*path);
+        genome_checker.CheckPathEnd(path->Conjugate());
     }
     INFO ("In total found " << total_mis << " misassemblies " << " and " << gap_mis << " gaps.");
 }
@@ -199,49 +200,87 @@ void PathExtendLauncher::DebugOutputPaths(const PathContainer &paths, const stri
     if (!params_.pe_cfg.debug_output) {
         return;
     }
-    PathInfoWriter path_writer;
     PathVisualizer visualizer;
 
-    writer_.OutputPaths(paths, params_.etc_dir + name);
+    writer_.OutputPaths(paths, params_.etc_dir + name + ".fasta");
     if (params_.pe_cfg.output.write_paths) {
-        path_writer.WritePaths(paths, params_.etc_dir + name + ".dat");
+        std::ofstream oss(params_.etc_dir + name + ".dat");
+        for (auto iter = paths.begin(); iter != paths.end(); ++iter) {
+            iter.get()->Print(oss);
+        }
+        oss.close();
     }
     if (params_.pe_cfg.viz.print_paths) {
         visualizer.writeGraphWithPathsSimple(gp_, params_.etc_dir + name + ".dot", name, paths);
     }
 }
 
-void PathExtendLauncher::FinalizePaths(PathContainer &paths,
-                                       GraphCoverageMap &cover_map,
-                                       const PathExtendResolver &resolver) const {
+void FilterInterstandBulges(PathContainer &paths) {
+    DEBUG ("Try to delete paths with interstand bulges");
+    for (auto iter = paths.begin(); iter != paths.end(); ++iter) {
+        if (EndsWithInterstrandBulge(*iter.get())) {
+            iter.get()->PopBack();
+        }
+        if (EndsWithInterstrandBulge(*iter.getConjugate())) {
+            iter.getConjugate()->PopBack();
+        }
+    }
+    DEBUG("deleted paths with interstand bulges");
+}
 
-    if (params_.pset.remove_overlaps) {
+void PathExtendLauncher::RemoveOverlapsAndArtifacts(PathContainer &paths,
+                                                    GraphCoverageMap &cover_map,
+                                                    const PathExtendResolver &resolver) const {
+    INFO("Finalizing paths");
+
+    INFO("Deduplicating paths");
+    Deduplicate(gp_.g, paths, cover_map, params_.min_edge_len,
+                         params_.max_path_diff);
+
+    INFO("Paths deduplicated");
+
+    if (params_.pset.overlap_removal.enabled) {
         resolver.RemoveOverlaps(paths, cover_map, params_.min_edge_len, params_.max_path_diff,
-                                 params_.pset.cut_all_overlaps,
-                                 (params_.mode == config::pipeline_type::moleculo));
-    } else if (params_.mode == config::pipeline_type::rna) {
-        resolver.RemoveRNAOverlaps(paths, cover_map, params_.min_edge_len, params_.max_path_diff);
+                                params_.pset.overlap_removal.end_start_only,
+                                params_.pset.overlap_removal.cut_all);
     } else {
-        resolver.RemoveEqualPaths(paths, cover_map, params_.min_edge_len);
+        INFO("Overlaps will not be removed");
     }
 
+    //TODO do we still need it?
     if (params_.avoid_rc_connections) {
-        paths.FilterInterstandBulges();
+        FilterInterstandBulges(paths);
     }
-    paths.FilterEmptyPaths();
     resolver.AddUncoveredEdges(paths, cover_map);
 
-    if (params_.pset.path_filtration.enabled) {
-        LengthPathFilter(gp_.g, params_.pset.path_filtration.min_length).filter(paths);;
-        IsolatedPathFilter(gp_.g,
-                           params_.pset.path_filtration.min_length_for_low_covered,
-                           params_.pset.path_filtration.min_coverage).filter(paths);
-        IsolatedPathFilter(gp_.g, params_.pset.path_filtration.isolated_min_length).filter(paths);
-    }
     paths.SortByLength();
-    for (auto &path : paths) {
-        path.first->ResetOverlaps();
+    INFO("Paths finalized");
+}
+
+
+void PathExtendLauncher::CleanPaths(PathContainer &paths, const pe_config::ParamSetT::PathFiltrationT &path_filtration) const {
+    if (path_filtration.enabled) {
+        paths.FilterPaths(LengthPathCondition(GetLengthCutoff(path_filtration.min_length, path_filtration.rel_cutoff)));
+        paths.FilterPaths(func::And(CoveragePathCondition(gp_.g, path_filtration.min_coverage),
+                                    LengthPathCondition(GetLengthCutoff(path_filtration.min_length_for_low_covered, path_filtration.rel_low_covered_cutoff))));
+        paths.FilterPaths(func::And(IsolatedPathCondition(gp_.g),
+                                    func::And(LengthPathCondition(GetLengthCutoff(path_filtration.isolated_min_length, path_filtration.rel_isolated_cutoff)),
+                                              CoveragePathCondition(gp_.g, path_filtration.isolated_min_cov))));
     }
+
+    paths.SortByLength();
+}
+
+
+size_t PathExtendLauncher::GetLengthCutoff(size_t abs_cutoff, double rel_cutoff) const {
+    int rel_len = int(rel_cutoff * double(cfg::get().ds.RL())) - int(cfg::get().K);
+    int abs_len = int(abs_cutoff) - int(cfg::get().K);
+    size_t result = (size_t) max(0, max(rel_len, abs_len));
+
+    INFO("Read length relative cutoff " << rel_cutoff << " converted to " << rel_len);
+    INFO("Read length absolute cutoff " << abs_cutoff << " bp converted to " << result);
+    INFO("Length cutoff: " << result);
+    return result;
 }
 
 void PathExtendLauncher::TraverseLoops(PathContainer &paths, GraphCoverageMap &cover_map) const {
@@ -258,34 +297,30 @@ void PathExtendLauncher::TraverseLoops(PathContainer &paths, GraphCoverageMap &c
     INFO("Traversed " << res << " loops");
 }
 
-Extenders PathExtendLauncher::ConstructMPExtender(const ExtendersGenerator &generator, size_t uniqe_edge_len) {
-    ScaffoldingUniqueEdgeAnalyzer additional_edge_analyzer(gp_, (size_t) uniqe_edge_len, unique_data_.unique_variation_);
-    unique_data_.unique_storages_.push_back(make_shared<ScaffoldingUniqueEdgeStorage>());
-    additional_edge_analyzer.FillUniqueEdgeStorage(*unique_data_.unique_storages_.back());
-
-    return generator.MakeMPExtenders(*unique_data_.unique_storages_.back());
+void PathExtendLauncher::AddScaffUniqueStorage(size_t uniqe_edge_len) {
+    ScaffoldingUniqueEdgeAnalyzer additional_edge_analyzer(gp_, (size_t) uniqe_edge_len,
+                                                           unique_data_.unique_variation_);
+    unique_data_.unique_storages_.push_back(ScaffoldingUniqueEdgeStorage());
+    additional_edge_analyzer.FillUniqueEdgeStorage(unique_data_.unique_storages_.back());
 }
 
 Extenders PathExtendLauncher::ConstructMPExtenders(const ExtendersGenerator &generator) {
     const pe_config::ParamSetT &pset = params_.pset;
 
-    Extenders extenders =  generator.MakeMPExtenders(unique_data_.main_unique_storage_);
-    INFO("Using " << extenders.size() << " mate-pair " << support_.LibStr(extenders.size()));
-
     size_t cur_length = unique_data_.min_unique_length_ - pset.scaffolding2015.unique_length_step;
     size_t lower_bound = max(pset.scaffolding2015.unique_length_lower_bound, pset.scaffolding2015.unique_length_step);
 
     while (cur_length > lower_bound) {
-        INFO("Adding extender with length " << cur_length);
-        push_back_all(extenders, ConstructMPExtender(generator, cur_length));
+        INFO("Will add extenders for length " << cur_length);
+        AddScaffUniqueStorage(cur_length);
         cur_length -= pset.scaffolding2015.unique_length_step;
     }
     if (unique_data_.min_unique_length_ > lower_bound) {
-        INFO("Adding final extender with length " << lower_bound);
-        push_back_all(extenders, ConstructMPExtender(generator, lower_bound));
+        INFO("Will add final extenders for length " << lower_bound);
+        AddScaffUniqueStorage(lower_bound);
     }
 
-    return extenders;
+    return generator.MakeMPExtenders();
 }
 
 void PathExtendLauncher::FillPathContainer(size_t lib_index, size_t size_threshold) {
@@ -300,17 +335,17 @@ void PathExtendLauncher::FillPathContainer(size_t lib_index, size_t size_thresho
         BidirectionalPath *conj_path = new BidirectionalPath(new_path->Conjugate());
         new_path->SetWeight((float) path.getWeight());
         conj_path->SetWeight((float) path.getWeight());
-        unique_data_.long_reads_paths_[lib_index]->AddPair(new_path, conj_path);
+        unique_data_.long_reads_paths_[lib_index].AddPair(new_path, conj_path);
     }
-    DEBUG("Long reads paths " << unique_data_.long_reads_paths_[lib_index]->size());
-    unique_data_.long_reads_cov_map_[lib_index]->AddPaths(*unique_data_.long_reads_paths_[lib_index]);
+    DEBUG("Long reads paths " << unique_data_.long_reads_paths_[lib_index].size());
+    unique_data_.long_reads_cov_map_[lib_index].AddPaths(unique_data_.long_reads_paths_[lib_index]);
 }
 
 
 void PathExtendLauncher::FillLongReadsCoverageMaps() {
     for (size_t lib_index = 0; lib_index < dataset_info_.reads.lib_count(); lib_index++) {
-        unique_data_.long_reads_paths_.push_back(make_shared<PathContainer>());
-        unique_data_.long_reads_cov_map_.push_back(make_shared<GraphCoverageMap>(gp_.g));
+        unique_data_.long_reads_paths_.push_back(PathContainer());
+        unique_data_.long_reads_cov_map_.push_back(GraphCoverageMap(gp_.g));
         if (support_.IsForSingleReadExtender(dataset_info_.reads[lib_index])) {
             FillPathContainer(lib_index);
         }
@@ -319,6 +354,7 @@ void PathExtendLauncher::FillLongReadsCoverageMaps() {
 
 void  PathExtendLauncher::FillPBUniqueEdgeStorages() {
     //FIXME magic constants
+    //FIXME need to change for correct usage of prelimnary contigs in loops
     ScaffoldingUniqueEdgeAnalyzer unique_edge_analyzer_pb(gp_, 500, 0.5);
 
     INFO("Filling backbone edges for long reads scaffolding...");
@@ -348,26 +384,26 @@ void  PathExtendLauncher::FillPBUniqueEdgeStorages() {
 
 Extenders PathExtendLauncher::ConstructPBExtenders(const ExtendersGenerator &generator) {
     FillPBUniqueEdgeStorages();
-    return generator.MakePBScaffoldingExtenders(unique_data_.unique_pb_storage_,
-                                                unique_data_.long_reads_cov_map_);
+    return generator.MakePBScaffoldingExtenders();
 }
 
 
-Extenders PathExtendLauncher::ConstructExtenders(const GraphCoverageMap& cover_map) {
+Extenders PathExtendLauncher::ConstructExtenders(const GraphCoverageMap &cover_map,
+                                                 UsedUniqueStorage &used_unique_storage) {
     INFO("Creating main extenders, unique edge length = " << unique_data_.min_unique_length_);
     if (support_.SingleReadsMapped() || support_.HasLongReads())
         FillLongReadsCoverageMaps();
 
-    ExtendersGenerator generator(dataset_info_, params_, gp_, cover_map, support_);
-    Extenders extenders = generator.MakeBasicExtenders(unique_data_.main_unique_storage_,
-                                                       unique_data_.long_reads_cov_map_);
+    ExtendersGenerator generator(dataset_info_, params_, gp_, cover_map,
+                                 unique_data_, used_unique_storage, support_);
+    Extenders extenders = generator.MakeBasicExtenders();
 
     //long reads scaffolding extenders.
     if (support_.HasLongReads()) {
         if (params_.pset.sm == sm_old) {
             INFO("Will not use new long read scaffolding algorithm in this mode");
         } else {
-            push_back_all(extenders, ConstructPBExtenders(generator));
+            utils::push_back_all(extenders, ConstructPBExtenders(generator));
         }
     }
 
@@ -375,26 +411,69 @@ Extenders PathExtendLauncher::ConstructExtenders(const GraphCoverageMap& cover_m
         if (params_.pset.sm == sm_old) {
             INFO("Will not use mate-pairs is this mode");
         } else {
-            push_back_all(extenders, ConstructMPExtenders(generator));
+            utils::push_back_all(extenders, ConstructMPExtenders(generator));
         }
     }
 
     if (params_.pset.use_coordinated_coverage)
-        push_back_all(extenders, generator.MakeCoverageExtenders());
+        utils::push_back_all(extenders, generator.MakeCoverageExtenders());
 
     INFO("Total number of extenders is " << extenders.size());
     return extenders;
 }
 
-void PathExtendLauncher::PolishPaths(const PathContainer &paths, PathContainer &result) const {
+void PathExtendLauncher::PolishPaths(const PathContainer &paths, PathContainer &result,
+                                     const GraphCoverageMap& /* cover_map */) const {
     //Fixes distances for paths gaps and tries to fill them in
     INFO("Closing gaps in paths");
-    PathPolisher polisher(gp_, dataset_info_, unique_data_.main_unique_storage_, params_.max_polisher_gap);
-    polisher.PolishPaths(paths, result);
+
+    vector<shared_ptr<PathGapCloser>> gap_closers;
+
+    gap_closers.push_back(make_shared<DijkstraGapCloser>(gp_.g, params_.max_polisher_gap));
+    for (size_t i = 0; i < dataset_info_.reads.lib_count(); i++) {
+        auto lib = dataset_info_.reads[i];
+        if (lib.type() == io::LibraryType::HQMatePairs || lib.type() == io::LibraryType::MatePairs) {
+            shared_ptr<PairedInfoLibrary> paired_lib = MakeNewLib(gp_.g, lib, gp_.paired_indices[i]);
+            gap_closers.push_back(make_shared<MatePairGapCloser> (gp_.g, params_.max_polisher_gap, paired_lib,
+                                                                   unique_data_.main_unique_storage_));
+        }
+    }
+
+////TODO:: is it really empty?
+//    UniqueData unique_data;
+//    UsedUniqueStorage used_unique_storage(unique_data.main_unique_storage_);
+//    ExtendersGenerator generator(dataset_info_, params_, gp_, cover_map,
+//                                 unique_data, used_unique_storage, support_);
+//    auto polisher_storage = ScaffoldingUniqueEdgeStorage();
+//    for  (const auto& extender: generator.MakePEExtenders()) {
+//        gap_closers.push_back(make_shared<PathExtenderGapCloser>(gp_.g, params_.max_polisher_gap, extender));
+//    }
+//FIXME: uncomment cover_map 
+
+    PathPolisher polisher(gp_, gap_closers);
+    result = polisher.PolishPaths(paths);
     result.SortByLength();
     INFO("Gap closing completed")
 }
 
+void PathExtendLauncher::FilterPaths() {
+    PathContainer contig_paths_copy(gp_.contig_paths.begin(), gp_.contig_paths.end());
+    for (const auto& it: params_.pset.path_filtration) {
+        if (it.first == "default" && it.second.enabled) {
+            INFO("Finalizing main paths");
+            CleanPaths(gp_.contig_paths, it.second);
+            DebugOutputPaths(gp_.contig_paths, "final_paths");
+        }
+        else if (it.second.enabled) {
+            INFO("Finalizing paths - " + it.first);
+            PathContainer to_clean(contig_paths_copy.begin(), contig_paths_copy.end());
+            CleanPaths(to_clean, it.second);
+            DebugOutputPaths(to_clean, it.first + "_final_paths");
+            writer_.OutputPaths(to_clean, params_.output_dir + it.first + "_filtered_final_paths" + ".fasta");
+        }
+    }
+}
+
 void PathExtendLauncher::Launch() {
     INFO("ExSPAnder repeat resolving tool started");
     make_dir(params_.output_dir);
@@ -415,30 +494,37 @@ void PathExtendLauncher::Launch() {
     DebugOutputPaths(seeds, "init_paths");
 
     GraphCoverageMap cover_map(gp_.g);
-    Extenders extenders = ConstructExtenders(cover_map);
-    shared_ptr<CompositeExtender> composite_extender = make_shared<CompositeExtender>(gp_.g, cover_map, extenders,
-                                                                                      unique_data_.main_unique_storage_,
-                                                                                      params_.max_path_diff,
-                                                                                      params_.pset.extension_options.max_repeat_length,
-                                                                                      params_.detect_repeats_online);
+    UsedUniqueStorage used_unique_storage(unique_data_.main_unique_storage_);
+    Extenders extenders = ConstructExtenders(cover_map, used_unique_storage);
+    CompositeExtender composite_extender(gp_.g, cover_map,
+                                         used_unique_storage,
+                                         extenders,
+                                         params_.max_path_diff);
 
-    auto paths = resolver.ExtendSeeds(seeds, *composite_extender);
-    paths.FilterEmptyPaths();
-    paths.SortByLength();
+    auto paths = resolver.ExtendSeeds(seeds, composite_extender);
     DebugOutputPaths(paths, "raw_paths");
 
-    FinalizePaths(paths, cover_map, resolver);
+    RemoveOverlapsAndArtifacts(paths, cover_map, resolver);
     DebugOutputPaths(paths, "before_loop_traversal");
-
+    //TODO think about ordering of path polisher vs loop traversal
     TraverseLoops(paths, cover_map);
     DebugOutputPaths(paths, "loop_traveresed");
 
-    PolishPaths(paths, gp_.contig_paths);
+    //TODO does path polishing correctly work with coverage map
+    PolishPaths(paths, gp_.contig_paths, cover_map);
     DebugOutputPaths(gp_.contig_paths, "polished_paths");
-    
+
+    //TODO use move assignment to original map here
     GraphCoverageMap polished_map(gp_.g, gp_.contig_paths, true);
-    FinalizePaths(gp_.contig_paths, polished_map, resolver);
-    DebugOutputPaths(gp_.contig_paths, "final_paths");
+    RemoveOverlapsAndArtifacts(gp_.contig_paths, polished_map, resolver);
+    DebugOutputPaths(gp_.contig_paths, "overlap_removed");
+
+    if (params_.ss.ss_enabled) {
+        PathContainerCoverageSwitcher switcher(gp_.g, gp_.ss_coverage.front(), params_.ss.antisense);
+        switcher.Apply(gp_.contig_paths);
+    }
+
+    FilterPaths();
 
     CountMisassembliesWithReference(gp_.contig_paths);
 
