@@ -123,12 +123,12 @@ class BulgeGluer {
 
         EnsureEndsPositionAligner aligner(CumulativeLength(g_, path),
                 g_.length(edge));
-        double prefix_length = 0.;
+        size_t prefix_length = 0.;
         vector<size_t> bulge_prefix_lengths;
 
         for (EdgeId e : path) {
-            prefix_length += (double) g_.length(e);
-            bulge_prefix_lengths.push_back(aligner.GetPosition((size_t) prefix_length));
+            prefix_length += g_.length(e);
+            bulge_prefix_lengths.push_back(aligner.GetPosition(prefix_length));
         }
 
         EdgeId edge_to_split = edge;
@@ -210,6 +210,7 @@ class AlternativesAnalyzer {
     size_t max_delta_;
     double max_relative_delta_;
     size_t max_edge_cnt_;
+    size_t dijkstra_vertex_limit_;
 
     static vector<EdgeId> EmptyPath() {
         static vector<EdgeId> vec = {};
@@ -229,14 +230,16 @@ class AlternativesAnalyzer {
 public:
     AlternativesAnalyzer(const Graph& g, double max_coverage, size_t max_length,
                          double max_relative_coverage, size_t max_delta,
-                         double max_relative_delta, size_t max_edge_cnt) :
+                         double max_relative_delta, size_t max_edge_cnt,
+                         size_t dijkstra_vertex_limit) :
                          g_(g),
                          max_coverage_(max_coverage),
                          max_length_(max_length),
                          max_relative_coverage_(max_relative_coverage),
                          max_delta_(max_delta),
                          max_relative_delta_(max_relative_delta),
-                         max_edge_cnt_(max_edge_cnt) {
+                         max_edge_cnt_(max_edge_cnt),
+                         dijkstra_vertex_limit_(dijkstra_vertex_limit) {
         DEBUG("Created alternatives analyzer max_length=" << max_length
         << " max_coverage=" << max_coverage
         << " max_relative_coverage=" << max_relative_coverage
@@ -261,8 +264,10 @@ public:
         VertexId end = g_.EdgeEnd(e);
         TRACE("End " << g_.str(end));
 
-        ProcessPaths(g_, (g_.length(e) > delta) ? g_.length(e) - delta : 0,
-                g_.length(e) + delta, start, end, path_chooser, max_edge_cnt_);
+        size_t max_path_len = g_.length(e) + delta;
+        PathProcessor<Graph> processor(g_, start, max_path_len, dijkstra_vertex_limit_);
+        processor.Process(end, (g_.length(e) > delta) ? g_.length(e) - delta : 0,
+                          max_path_len, path_chooser, max_edge_cnt_);
 
         const vector<EdgeId>& path = path_chooser.most_covered_path();
         if (!path.empty()) {
@@ -307,6 +312,21 @@ NecessaryBulgeCondition(const Graph& g, size_t max_length, double max_coverage)
                                                      CoverageUpperBound<Graph>(g, max_coverage)));
 }
 
+template<class Graph>
+func::TypedPredicate<typename Graph::EdgeId>
+NecessaryBulgeCondition(const Graph& g, const AlternativesAnalyzer<Graph>& analyzer) {
+    return NecessaryBulgeCondition(g, analyzer.max_length(), analyzer.max_coverage());
+}
+
+template<class Graph>
+InterestingFinderPtr<Graph, typename Graph::EdgeId>
+BulgeCandidateFinder(const Graph &g,
+                     const AlternativesAnalyzer<Graph> &analyzer,
+                     size_t chunk_cnt) {
+    return std::make_shared<omnigraph::ParallelInterestingElementFinder<Graph>>(
+            omnigraph::NecessaryBulgeCondition(g, analyzer), chunk_cnt);
+};
+
 /**
  * This class removes simple bulges from given graph with the following algorithm: it iterates through all edges of
  * the graph and for each edge checks if this edge is likely to be a simple bulge
@@ -345,13 +365,13 @@ public:
 
     typedef std::function<void(EdgeId edge, const vector<EdgeId>& path)> BulgeCallbackF;
 
-    BulgeRemover(Graph& g, const std::shared_ptr<InterestingElementFinder<Graph, EdgeId>>& interesting_finder,
+    BulgeRemover(Graph& g, size_t chunk_cnt,
             const AlternativesAnalyzer<Graph>& alternatives_analyzer,
             BulgeCallbackF opt_callback = 0,
             std::function<void(EdgeId)> removal_handler = 0,
             bool track_changes = true) :
             base(g,
-                 interesting_finder,
+                 BulgeCandidateFinder(g, alternatives_analyzer, chunk_cnt),
                  /*canonical_only*/true,
                  CoverageComparator<Graph>(g),
                  track_changes),
@@ -369,9 +389,10 @@ private:
 template<class Graph>
 class ParallelBulgeRemover : public PersistentAlgorithmBase<Graph> {
 private:
+    static const size_t SMALL_BUFFER_THR = 1000;
     typedef typename Graph::EdgeId EdgeId;
     typedef typename Graph::VertexId VertexId;
-    typedef std::shared_ptr<InterestingElementFinder<Graph, EdgeId>> CandidateFinderPtr;
+    typedef InterestingFinderPtr<Graph, EdgeId> CandidateFinderPtr;
     typedef SmartSetIterator<Graph, EdgeId, CoverageComparator<Graph>> SmartEdgeSet;
 
     size_t buff_size_;
@@ -438,6 +459,12 @@ private:
 
     };
 
+    SmartEdgeSet AsSmartSet(const std::vector<EdgeId> &edges) {
+        SmartEdgeSet smart_set(this->g(), false, CoverageComparator<Graph>(this->g()));
+        smart_set.insert(edges.begin(), edges.end());
+        return smart_set;
+    }
+
     bool CheckInteracting(const BulgeInfo& info, const std::unordered_set<EdgeId>& involved_edges) const {
         if (involved_edges.count(info.e))
             return true;
@@ -462,55 +489,55 @@ private:
         }
     }
 
-    //false if time to stop
+    //returns false if time to stop
     bool FillEdgeBuffer(vector<EdgeId>& buffer, func::TypedPredicate<EdgeId> proceed_condition) {
         VERIFY(buffer.empty());
         DEBUG("Filling edge buffer of size " << buff_size_);
-        perf_counter perf;
-        double low_cov = 0.;
-        double cov_diff = 0.;
+        utils::perf_counter perf;
+        double max_cov = std::numeric_limits<double>::min();
+        bool exhausted = false;
+
         while (!it_.IsEnd() && buffer.size() < buff_size_) {
             EdgeId e = *it_;
             TRACE("Current edge " << this->g().str(e));
-            if (!proceed_condition(e)) {
-                TRACE("Stop condition was reached.");
-                //need to release last element of the iterator to make it replaceable by new elements
-                it_.ReleaseCurrent();
-                return false;
-            }
 
             double cov = this->g().coverage(e);
             if (buffer.empty()) {
-                low_cov = cov;
-                cov_diff = max(buff_cov_diff_, buff_cov_rel_diff_ * low_cov);
-            } else {
-                if (math::gr(cov, low_cov + cov_diff)) {
-                    //need to release last element of the iterator to make it replaceable by new elements
-                    it_.ReleaseCurrent();
-                    return true;
-                }
+                max_cov = cov + max(buff_cov_diff_, buff_cov_rel_diff_ * cov);
+                DEBUG("Coverage interval [" << cov << ", " << max_cov << "]");
             }
+
+            if (!proceed_condition(e)) {
+                DEBUG("Stop condition was reached.");
+                exhausted = true;
+                break;
+            }
+
+            if (math::gr(cov, max_cov)) {
+                DEBUG("Coverage exceeded " << cov << " > " << max_cov);
+                break;
+            }
+
             TRACE("Potential bulge edge");
             buffer.push_back(e);
             ++it_;
         }
 
+        exhausted |= it_.IsEnd();
+        it_.ReleaseCurrent();
+
         DEBUG("Filled in " << perf.time() << " seconds");
-        if (buffer.size() == buff_size_) {
-            TRACE("Buffer filled");
-            return true;
-        } else {
-            TRACE("No more edges in iterator");
-            return false;
-        }
+        DEBUG("Candidate queue exhausted " << exhausted);
+        return !exhausted;
     }
 
     std::vector<std::vector<BulgeInfo>> FindBulges(const std::vector<EdgeId>& edge_buffer) const {
-        DEBUG("Looking for bulges (in parallel). Edge buffer size " << edge_buffer.size());
-        perf_counter perf;
+        DEBUG("Looking for bulges in parallel");
+        utils::perf_counter perf;
         std::vector<std::vector<BulgeInfo>> bulge_buffers(omp_get_max_threads());
-        size_t n = edge_buffer.size();
+        const size_t n = edge_buffer.size();
         //order is in agreement with coverage
+        DEBUG("Edge buffer size " << n);
         #pragma omp parallel for schedule(guided)
         for (size_t i = 0; i < n; ++i) {
             EdgeId e = edge_buffer[i];
@@ -519,13 +546,13 @@ private:
                 bulge_buffers[omp_get_thread_num()].push_back(BulgeInfo(i, e, std::move(alternative)));
             }
         }
-        DEBUG("Bulges found in " << perf.time() << " seconds");
+        DEBUG("Bulges found (in parallel) in " << perf.time() << " seconds");
         return bulge_buffers;
     }
 
     std::vector<BulgeInfo> MergeBuffers(std::vector<std::vector<BulgeInfo>>&& buffers) const {
         DEBUG("Merging bulge buffers");
-        perf_counter perf;
+        utils::perf_counter perf;
 
         std::vector<BulgeInfo> merged_bulges;
         for (auto& bulge_buffer : buffers) {
@@ -545,7 +572,7 @@ private:
     SmartEdgeSet RetainIndependentBulges(std::vector<BulgeInfo>& bulges) const {
         DEBUG("Looking for independent bulges");
         size_t total_cnt = bulges.size();
-        perf_counter perf;
+        utils::perf_counter perf;
 
         std::vector<BulgeInfo> filtered;
         filtered.reserve(bulges.size());
@@ -574,9 +601,24 @@ private:
         return interacting_edges;
     }
 
-    size_t ProcessBulges(const std::vector<BulgeInfo>& independent_bulges, SmartEdgeSet&& interacting_edges) {
+    size_t BasicProcessBulges(SmartEdgeSet& edges) {
+        size_t triggered = 0;
+        //usual br strategy
+        for (; !edges.IsEnd(); ++edges) {
+            EdgeId e = *edges;
+            TRACE("Processing edge " << this->g().str(e));
+            std::vector<EdgeId> alternative = alternatives_analyzer_(e);
+            if (!alternative.empty()) {
+                gluer_(e, alternative);
+                triggered++;
+            }
+        }
+        return triggered;
+    }
+
+    size_t ProcessBulges(const std::vector<BulgeInfo>& independent_bulges, SmartEdgeSet& interacting_edges) {
         DEBUG("Processing bulges");
-        perf_counter perf;
+        utils::perf_counter perf;
 
         size_t triggered = 0;
 
@@ -590,16 +632,7 @@ private:
         perf.reset();
 
         DEBUG("Processing remaining interacting bulges " << interacting_edges.size());
-        //usual br strategy
-        for (; !interacting_edges.IsEnd(); ++interacting_edges) {
-            EdgeId e = *interacting_edges;
-            TRACE("Processing edge " << this->g().str(e));
-            std::vector<EdgeId> alternative = alternatives_analyzer_(e);
-            if (!alternative.empty()) {
-                gluer_(e, alternative);
-                triggered++;
-            }
-        }
+        triggered += BasicProcessBulges(interacting_edges);
         DEBUG("Interacting edges processed in " << perf.time() << " seconds");
         return triggered;
     }
@@ -608,22 +641,29 @@ public:
 
     typedef std::function<void(EdgeId edge, const vector<EdgeId>& path)> BulgeCallbackF;
 
-    ParallelBulgeRemover(Graph& g, const CandidateFinderPtr& interesting_edge_finder,
-                         size_t buff_size, double buff_cov_diff,
-                         double buff_cov_rel_diff, const AlternativesAnalyzer<Graph>& alternatives_analyzer,
+    ParallelBulgeRemover(Graph& g,
+                         size_t chunk_cnt,
+                         size_t buff_size,
+                         double buff_cov_diff,
+                         double buff_cov_rel_diff,
+                         const AlternativesAnalyzer<Graph>& alternatives_analyzer,
                          BulgeCallbackF opt_callback = 0,
                          std::function<void(EdgeId)> removal_handler = 0,
                          bool track_changes = true) :
+
                          PersistentAlgorithmBase<Graph>(g),
                          buff_size_(buff_size),
                          buff_cov_diff_(buff_cov_diff),
                          buff_cov_rel_diff_(buff_cov_rel_diff),
                          alternatives_analyzer_(alternatives_analyzer),
                          gluer_(g, opt_callback, removal_handler),
-                         interesting_edge_finder_(interesting_edge_finder),
+                         interesting_edge_finder_(BulgeCandidateFinder(g, alternatives_analyzer, chunk_cnt)),
                          tracking_(track_changes),
                          curr_iteration_(0),
-                         it_(g, true, CoverageComparator<Graph>(g), true) {
+                         it_(g, /*add new*/true,
+                             CoverageComparator<Graph>(g),
+                             /*canonical only*/true,
+                             NecessaryBulgeCondition(g, alternatives_analyzer)) {
         VERIFY(buff_size_ > 0);
         it_.Detach();
     }
@@ -639,32 +679,46 @@ public:
         }
         if (primary_launch) {
             it_.clear();
-            TRACE("Primary launch.");
-            TRACE("Start search for interesting edges");
+            DEBUG("Primary launch.");
+            DEBUG("Start search for interesting edges");
             interesting_edge_finder_->Run(this->g(), [&](EdgeId e) {it_.push(e);});
-            TRACE(it_.size() << " interesting edges to process");
+            DEBUG(it_.size() << " interesting edges to process");
         } else {
             VERIFY(tracking_);
-            TRACE(it_.size() << " edges to process");
+            DEBUG(it_.size() << " edges to process");
         }
 
         size_t triggered = 0;
         bool proceed = true;
         while (proceed) {
             std::vector<EdgeId> edge_buffer;
+            DEBUG("Filling edge buffer");
             edge_buffer.reserve(buff_size_);
             proceed = FillEdgeBuffer(edge_buffer, proceed_condition);
+            DEBUG("Edge buffer filled");
 
-            std::vector<BulgeInfo> bulges = MergeBuffers(FindBulges(edge_buffer));
+            DEBUG("Edge buffer size " << edge_buffer.size());
+            size_t inner_triggered = 0;
+            //FIXME magic constant
+            if (edge_buffer.size() < SMALL_BUFFER_THR) {
+                DEBUG("Processing small buffer");
+                utils::perf_counter perf;
+                //TODO implement via moves?
+                auto edges = AsSmartSet(edge_buffer);
+                inner_triggered = BasicProcessBulges(edges);
+                DEBUG("Small buffer processed in " << perf.time() << " seconds");
+            } else {
+                std::vector<BulgeInfo> bulges = MergeBuffers(FindBulges(edge_buffer));
+                auto interacting_edges = RetainIndependentBulges(bulges);
+                inner_triggered = ProcessBulges(bulges, interacting_edges);
+            }
 
-            auto interacting_edges = RetainIndependentBulges(bulges);
-
-            size_t inner_triggered = ProcessBulges(bulges, std::move(interacting_edges));
             proceed |= (inner_triggered > 0);
             triggered += inner_triggered;
+            DEBUG("Buffer processed");
         }
 
-        TRACE("Finished processing. Triggered = " << triggered);
+        DEBUG("Finished processing. Triggered = " << triggered);
         if (!tracking_)
             it_.Detach();
 
