@@ -340,22 +340,7 @@ public:
     bool ShouldFilterConjugate() const {
         return true;
     }
-//    bool operator()(EdgeId e) {
-//        if (ec_condition_->Check(e)) {
-//            edges_to_remove_.push_back(e);
-//        }
-//        return false;
-//    }
-//
-//    void RemoveCollectedEdges() {
-//        omnigraph::SmartSetIterator<Graph, EdgeId> to_delete(g_, edges_to_remove_.begin(), edges_to_remove_.end());
-//        while (!to_delete.IsEnd()) {
-//            EdgeId e = *to_delete;
-//            handler_f_(e);
-//            g_.DeleteEdge(e);
-//            ++to_delete;
-//        }
-//    }
+
 private:
     DECL_LOGGER("ParallelLowCoverageFunctor");
 };
@@ -727,70 +712,6 @@ private:
     ;
 };
 
-template<class Graph, class ElementType>
-class SemiParallelAlgorithmRunner {
-    typedef typename Graph::VertexId VertexId;
-    typedef typename Graph::EdgeId EdgeId;
-
-    const Graph& g_;
-
-public:
-
-    const Graph& g() const {
-        return g_;
-    }
-
-    SemiParallelAlgorithmRunner(Graph& g)
-            : g_(g) {
-
-    }
-
-    template<class Algo, class ItVec, class Comparator = std::less<ElementType>>
-    bool RunFromChunkIterators(Algo& algo, const ItVec& chunk_iterators,
-            const Comparator& comp = Comparator()) {
-        VERIFY(chunk_iterators.size() > 1);
-        omnigraph::SmartSetIterator<Graph, ElementType, Comparator> it(g_, false, comp);
-
-        omnigraph::FindInterestingFromChunkIterators(chunk_iterators,
-                                          [&](ElementType el) {return algo.IsOfInterest(el);},
-                                          [&](ElementType el) {it.push(el);});
-
-        bool changed = false;
-        for (; !it.IsEnd(); ++it) {
-            changed |= algo.Process(*it);
-        }
-        return changed;
-    }
-
-private:
-    DECL_LOGGER("SemiParallelAlgorithmRunner");
-};
-
-template<class Graph>
-class SemiParallelEdgeRemovingAlgorithm {
-    typedef typename Graph::EdgeId EdgeId;
-    typedef typename Graph::VertexId VertexId;
-    Graph& g_;
-    func::TypedPredicate<EdgeId> condition_;
-    omnigraph::EdgeRemover<Graph> edge_remover_;
-
-public:
-    SemiParallelEdgeRemovingAlgorithm(Graph& g,
-                                      func::TypedPredicate<EdgeId> condition,
-                                      std::function<void(EdgeId)> removal_handler = 0) :
-            g_(g), condition_(condition), edge_remover_(g, removal_handler) {
-    }
-
-    bool IsOfInterest(EdgeId e) const {
-        return condition_(e);
-    }
-
-    bool Process(EdgeId e) {
-        edge_remover_.DeleteEdge(e);
-        return true;
-    }
-};
-
 template<class Graph, class AlgoRunner, class Algo>
 bool RunVertexAlgorithm(Graph& g, AlgoRunner& runner, Algo& algo, size_t chunk_cnt) {
     return runner.RunFromChunkIterators(algo, omnigraph::IterationHelper<Graph, typename Graph::VertexId>(g).Chunks(chunk_cnt));
@@ -801,6 +722,7 @@ bool RunEdgeAlgorithm(Graph& g, AlgoRunner& runner, Algo& algo, size_t chunk_cnt
     return runner.RunFromChunkIterators(algo, omnigraph::IterationHelper<Graph, typename Graph::EdgeId>(g).Chunks(chunk_cnt));
 }
 
+//Deprecated
 template<class Graph>
 void ParallelCompress(Graph &g, size_t chunk_cnt, bool loop_post_compression = true) {
     INFO("Parallel compression");
@@ -817,6 +739,7 @@ void ParallelCompress(Graph &g, size_t chunk_cnt, bool loop_post_compression = t
     }
 }
 
+//Deprecated
 template<class Graph>
 bool ParallelClipTips(Graph &g,
                       size_t max_length,
@@ -839,6 +762,7 @@ bool ParallelClipTips(Graph &g,
     return true;
 }
 
+//TODO review if can be useful... AFAIK never actually worked
 //template<class Graph>
 //bool ParallelRemoveBulges(Graph &g,
 //              const config::debruijn_config::simplification::bulge_remover &br_config,
@@ -867,6 +791,8 @@ bool ParallelClipTips(Graph &g,
 //    return true;
 //}
 
+//TODO looks obsolete
+//Deprecated
 template<class Graph>
 bool ParallelEC(Graph &g,
                 size_t max_length,
