@@ -7,7 +7,7 @@
 #include "pipeline/config_struct.hpp"
 
 #include "pipeline/config_common.hpp"
-#include "utils/openmp_wrapper.h"
+#include "utils/parallel/openmp_wrapper.h"
 
 #include "utils/logger/logger.hpp"
 #include "utils/verify.hpp"
@@ -249,6 +249,7 @@ void load(debruijn_config::simplification::bulge_remover& br,
   load(br.max_delta,                        pt,     "max_delta", complete);
   load(br.max_relative_delta,               pt,     "max_relative_delta", complete);
   load(br.max_number_edges,                 pt,     "max_number_edges", complete);
+  load(br.dijkstra_vertex_limit,            pt,     "dijkstra_vertex_limit", complete);
   load(br.parallel,                         pt,     "parallel", complete);
   load(br.buff_size,                        pt,     "buff_size", complete);
   load(br.buff_cov_diff,                    pt,     "buff_cov_diff", complete);
@@ -292,13 +293,22 @@ void load(debruijn_config::simplification::relative_coverage_comp_remover& rcc,
   load(rcc.max_coverage_coeff, pt, "max_coverage_coeff", complete);
 }
 
-void load(debruijn_config::simplification::isolated_edges_remover& ier,
+void load(debruijn_config::simplification::isolated_edge_remover& ier,
           boost::property_tree::ptree const& pt, bool complete) {
   using config_common::load;
   load(ier.enabled, pt, "enabled", complete);
   load(ier.max_length, pt, "max_length", complete);
+  load(ier.use_rl_for_max_length, pt, "use_rl_for_max_length", complete);
   load(ier.max_coverage, pt, "max_coverage", complete);
   load(ier.max_length_any_cov, pt, "max_length_any_cov", complete);
+  load(ier.use_rl_for_max_length_any_cov, pt, "use_rl_for_max_length_any_cov", complete);
+}
+
+void load(debruijn_config::simplification::low_covered_edge_remover& lcer,
+          boost::property_tree::ptree const& pt, bool complete) {
+  using config_common::load;
+  load(lcer.enabled, pt, "lcer_enabled", complete);
+  load(lcer.coverage_threshold, pt, "lcer_coverage_threshold", complete);
 }
 
 void load(debruijn_config::simplification::init_cleaning& init_clean,
@@ -517,6 +527,13 @@ void load(debruijn_config::graph_read_corr_cfg& graph_read_corr,
   load(graph_read_corr.binary, pt, "binary");
 }
 
+void load(debruijn_config::strand_specificity& ss,
+          boost::property_tree::ptree const& pt, bool /*complete*/) {
+    using config_common::load;
+    load(ss.ss_enabled, pt, "ss_enabled");
+    load(ss.antisense, pt, "antisense");
+}
+
 void load(debruijn_config::kmer_coverage_model& kcm,
           boost::property_tree::ptree const& pt, bool /*complete*/) {
   using config_common::load;
@@ -544,23 +561,27 @@ void load_reads(dataset &ds,
                 std::string input_dir) {
     if (ds.reads_filename[0] != '/')
         ds.reads_filename = input_dir + ds.reads_filename;
-    path::CheckFileExistenceFATAL(ds.reads_filename);
+    fs::CheckFileExistenceFATAL(ds.reads_filename);
     ds.reads.load(ds.reads_filename);
 }
 
 void load_reference_genome(dataset &ds,
                            std::string input_dir) {
     if (ds.reference_genome_filename == "") {
-        ds.reference_genome = "";
+        ds.reference_genome = vector<std::string>(0);
         return;
     }
     if (ds.reference_genome_filename[0] != '/')
         ds.reference_genome_filename = input_dir + ds.reference_genome_filename;
-    path::CheckFileExistenceFATAL(ds.reference_genome_filename);
+    fs::CheckFileExistenceFATAL(ds.reference_genome_filename);
     io::FileReadStream genome_stream(ds.reference_genome_filename);
-    io::SingleRead genome;
-    genome_stream >> genome;
-    ds.reference_genome = genome.GetSequenceString();
+    while (!genome_stream.eof()) {
+        io::SingleRead genome;
+        genome_stream >> genome;
+        ds.reference_genome.push_back(genome.GetSequenceString());
+    }
+
+
 }
 
 void load(debruijn_config::simplification& simp,
@@ -591,8 +612,6 @@ void load(debruijn_config::simplification& simp,
   load(simp.init_clean, pt, "init_clean", complete); // presimplification
   load(simp.final_tc, pt, "final_tc", complete);
   load(simp.final_br, pt, "final_br", complete);
-  simp.second_final_br = simp.final_br;
-  load(simp.second_final_br, pt, "second_final_br", false);
 }
 
 void load(debruijn_config::info_printer& printer,
@@ -650,7 +669,7 @@ void load_launch_info(debruijn_config &cfg, boost::property_tree::ptree const &p
     // input options:
     load(cfg.dataset_file, pt, "dataset");
     // input dir is based on dataset file location (all paths in datasets are relative to its location)
-    cfg.input_dir = path::parent_path(cfg.dataset_file);
+    cfg.input_dir = fs::parent_path(cfg.dataset_file);
     if (cfg.input_dir[cfg.input_dir.length() - 1] != '/')
         cfg.input_dir += '/';
 
@@ -702,7 +721,7 @@ void load_launch_info(debruijn_config &cfg, boost::property_tree::ptree const &p
 
     load(cfg.max_memory, pt, "max_memory");
 
-    path::CheckFileExistenceFATAL(cfg.dataset_file);
+    fs::CheckFileExistenceFATAL(cfg.dataset_file);
     boost::property_tree::ptree ds_pt;
     boost::property_tree::read_info(cfg.dataset_file, ds_pt);
     load(cfg.ds, ds_pt, true);
@@ -725,8 +744,6 @@ void load_cfg(debruijn_config &cfg, boost::property_tree::ptree const &pt,
 
     load(cfg.co, pt, "contig_output", complete);
 
-    load(cfg.use_unipaths, pt, "use_unipaths", complete);
-
     load(cfg.pb, pt, "pacbio_processor", complete);
 
     load(cfg.two_step_rr, pt, "two_step_rr", complete);
@@ -753,6 +770,8 @@ void load_cfg(debruijn_config &cfg, boost::property_tree::ptree const &pt,
     load(cfg.flanking_range, pt, "flanking_range", complete);
     load(cfg.graph_read_corr, pt, "graph_read_corr", complete);
     load(cfg.kcm, pt, "kmer_coverage_model", complete);
+    //TODO come up with a fix to this hack
+    load(cfg.simp.lcer, pt, "lcer", complete); //low coverage edge remover
     load(cfg.pos, pt, "pos", complete); // position handler:
 
     load(cfg.rm, pt, "resolving_mode", complete);
@@ -763,12 +782,23 @@ void load_cfg(debruijn_config &cfg, boost::property_tree::ptree const &pt,
 
     load(cfg.sensitive_map, pt, "sensitive_mapper", complete);
 
+    bool save_gp;
+    load(save_gp, pt, "save_gp", complete);
     load(cfg.info_printers, pt, "info_printers", complete);
 
+    if (save_gp) {
+        INFO("Graph pack will be saved before repeat resolution");
+        cfg.info_printers[info_printer_pos::before_repeat_resolution].save_graph_pack = true;
+    }
+
     load(cfg.bwa, pt, "bwa_aligner", complete);
 
     load(cfg.series_analysis, pt, "series_analysis", complete);
 
+    load(cfg.ss, pt, "strand_specificity", complete);
+    load(cfg.calculate_coverage_for_each_lib, pt, "calculate_coverage_for_each_lib", complete);
+
+
     if (pt.count("plasmid")) {
         VERIFY_MSG(!cfg.pd, "Option can be loaded only once");
         cfg.pd.reset(debruijn_config::plasmid());
