@@ -171,11 +171,6 @@ class DataPrinter {
         }
     }
 
-//    template<class C>
-//    void SaveEdgeAssociatedInfo(const C& c, ostream& out) const {
-//        SaveEdgeAssociatedInfo<decltype(C::operator[])>(boost::bind(&C::operator[], c, _1), out);
-//    }
-
     template<class C>
     void SaveEdgeAssociatedInfo(const C& c, ostream& out) const {
         out << component_.e_size() << endl;
@@ -220,7 +215,6 @@ class DataPrinter {
     void SaveEdgeSequences(const string& file_name) const {
         ofstream out(file_name + ".sqn");
         //todo switch to general function after its switching to fasta
-        //SaveEdgeAssociatedInfo<Sequence>(boost::bind(&Graph::EdgeNucls, component_.g(), _1), out);
         DEBUG("Saving sequences, " << file_name <<" created");
         for (auto iter = component_.e_begin(); iter != component_.e_end(); ++iter) {
             EdgeId e = *iter;
@@ -411,11 +405,6 @@ class DataScanner {
         }
     }
 
-//    template<class C>
-//    void LoadEdgeAssociatedInfo(const C& c, ostream& out) const {
-//        SaveEdgeAssociatedInfo<decltype(C::operator[])>(boost::bind(&C::operator[], c, _1), out);
-//    }
-
   public:
     virtual void LoadGraph(const string& file_name) = 0;
 
@@ -426,7 +415,7 @@ class DataScanner {
     }
 
     bool LoadFlankingCoverage(const string& file_name, FlankingCoverage<Graph>& flanking_cov) {
-        if (!path::FileExists(file_name + ".flcvr")) {
+        if (!fs::FileExists(file_name + ".flcvr")) {
             INFO("Flanking coverage saves are absent");
             return false;
         }
@@ -659,7 +648,7 @@ private:
 
 inline std::string MakeSingleReadsFileName(const std::string& file_name,
                                     size_t index) {
-    return file_name + "_paths_" + ToString(index) + ".mpr";
+    return file_name + "_paths_" + std::to_string(index) + ".mpr";
 }
 
 //helper methods
@@ -728,21 +717,21 @@ template<class Graph>
 void PrintUnclusteredIndices(const string& file_name, DataPrinter<Graph>& printer,
                              const UnclusteredPairedInfoIndicesT<Graph>& paired_indices) {
     for (size_t i = 0; i < paired_indices.size(); ++i)
-        PrintUnclusteredIndex(file_name + "_" + ToString(i), printer, paired_indices[i]);
+        PrintUnclusteredIndex(file_name + "_" + std::to_string(i), printer, paired_indices[i]);
 }
 
 template<class Graph>
 void PrintClusteredIndices(const string& file_name, DataPrinter<Graph>& printer,
                            const PairedInfoIndicesT<Graph>& paired_indices) {
     for (size_t i = 0; i < paired_indices.size(); ++i)
-        PrintClusteredIndex(file_name  + "_" + ToString(i), printer, paired_indices[i]);
+        PrintClusteredIndex(file_name  + "_" + std::to_string(i), printer, paired_indices[i]);
 }
 
 template<class Graph>
 void PrintScaffoldingIndices(const string& file_name, DataPrinter<Graph>& printer,
                            const PairedInfoIndicesT<Graph>& paired_indices) {
     for (size_t i = 0; i < paired_indices.size(); ++i)
-        PrintScaffoldingIndex(file_name  + "_" + ToString(i), printer, paired_indices[i]);
+        PrintScaffoldingIndex(file_name  + "_" + std::to_string(i), printer, paired_indices[i]);
 }
 
 template<class graph_pack>
@@ -920,7 +909,7 @@ void ScanPairedIndices(const std::string& file_name, DataScanner<Graph>& scanner
                        UnclusteredPairedInfoIndicesT<Graph>& paired_indices,
                        bool force_exists = true) {
     for (size_t i = 0; i < paired_indices.size(); ++i)
-        ScanPairedIndex(file_name  + "_" + ToString(i), scanner, paired_indices[i], force_exists);
+        ScanPairedIndex(file_name  + "_" + std::to_string(i), scanner, paired_indices[i], force_exists);
 }
 
 template<class Graph>
@@ -928,7 +917,7 @@ void ScanClusteredIndices(const std:: string& file_name, DataScanner<Graph>& sca
                           PairedInfoIndicesT<Graph>& paired_indices,
                           bool force_exists = true) {
     for (size_t i = 0; i < paired_indices.size(); ++i)
-        ScanClusteredIndex(file_name  + "_" + ToString(i), scanner, paired_indices[i], force_exists);
+        ScanClusteredIndex(file_name  + "_" + std::to_string(i), scanner, paired_indices[i], force_exists);
 }
 
 template<class Graph>
@@ -936,7 +925,7 @@ void ScanScaffoldingIndices(const std:: string& file_name, DataScanner<Graph>& s
                             PairedInfoIndicesT<Graph>& paired_indices,
                             bool force_exists = true) {
     for (size_t i = 0; i < paired_indices.size(); ++i)
-        ScanScaffoldingIndex(file_name  + "_" + ToString(i), scanner, paired_indices[i], force_exists);
+        ScanScaffoldingIndex(file_name  + "_" + std::to_string(i), scanner, paired_indices[i], force_exists);
 }
 
 template<class Graph>
@@ -944,7 +933,7 @@ void ScanScaffoldIndices(const string& file_name, DataScanner<Graph>& scanner,
         PairedInfoIndicesT<Graph>& scaffold_indices) {
 
     for (size_t i = 0; i < scaffold_indices.size(); ++i) {
-        ScanScaffoldIndex(file_name  + "_" + ToString(i), scanner, scaffold_indices[i]);
+        ScanScaffoldIndex(file_name  + "_" + std::to_string(i), scanner, scaffold_indices[i]);
     }
 }
 
