@@ -11,6 +11,7 @@
 #include "stages/simplification_pipeline/graph_simplification.hpp"
 #include "stages/simplification_pipeline/single_cell_simplification.hpp"
 #include "stages/simplification_pipeline/rna_simplification.hpp"
+#include "modules/simplification/cleaner.hpp"
 
 #include "simplification.hpp"
 
@@ -59,17 +60,17 @@ class GraphSimplifier {
         return true;
     }
 
-    void RemoveShortPolyATEdges(size_t max_length,
-                                HandlerF removal_handler = 0, size_t chunk_cnt = 1) {
+    void RemoveShortPolyATEdges(HandlerF removal_handler, size_t chunk_cnt) {
         INFO("Removing short polyAT");
         EdgeRemover<Graph> er(g_, removal_handler);
-        ATCondition<Graph> condition (g_, 0.8, max_length, false);
-        for (auto iter = g_.SmartEdgeBegin(); !iter.IsEnd(); ++iter){
+        ATCondition<Graph> condition(g_, 0.8, false);
+        for (auto iter = g_.SmartEdgeBegin(/*canonical only*/true); !iter.IsEnd(); ++iter){
             if (g_.length(*iter) == 1 && condition.Check(*iter)) {
                 er.DeleteEdgeNoCompress(*iter);
             }
         }
-        ParallelCompress(g_, chunk_cnt);
+        omnigraph::CompressAllVertices(g_, chunk_cnt);
+        omnigraph::CleanIsolatedVertices(g_, chunk_cnt);
     }
 
     void InitialCleaning() {
@@ -85,8 +86,12 @@ class GraphSimplifier {
                 algos);
 
         if (info_container_.mode() == config::pipeline_type::rna){
-            RemoveShortPolyATEdges(1, removal_handler_, info_container_.chunk_cnt());
-            PushValid(ShortPolyATEdgesRemoverInstance(g_, 1, removal_handler_, info_container_.chunk_cnt()), "Short PolyA/T Edges",algos) ;
+            //TODO create algo
+            RemoveShortPolyATEdges(removal_handler_, info_container_.chunk_cnt());
+            PushValid(std::make_shared<omnigraph::ParallelEdgeRemovingAlgorithm<Graph>>(g_, func::And(LengthUpperBound<Graph>(g_, 1),
+                                                                                                      ATCondition<Graph>(g_, 0.8, false)),
+                                                                                     info_container_.chunk_cnt(), removal_handler_, true),
+                      "Short PolyA/T Edges", algos) ;
             PushValid(ATTipClipperInstance(g_, removal_handler_, info_container_.chunk_cnt()), "AT Tips", algos);
         }
 
@@ -113,7 +118,7 @@ class GraphSimplifier {
                               removal_handler_),
                     "Initial ec remover",
                     algos);
-
+            
             PushValid(
                     LowFlankDisconnectorInstance(g_, gp_.flanking_cov,
                                                  simplif_cfg_.init_clean.disconnect_flank_cov, info_container_,
@@ -255,12 +260,6 @@ class GraphSimplifier {
         //FIXME need better configuration
 
         if (info_container_.mode() == config::pipeline_type::meta) {
-            PushValid(
-                    BRInstance(g_, simplif_cfg_.second_final_br,
-                                       info_container_, removal_handler_),
-                    "Yet another final bulge remover",
-                    algos);
-
             EdgePredicate<Graph> meta_thorn_condition
                     = And(LengthUpperBound<Graph>(g_, LengthThresholdFinder::MaxErroneousConnectionLength(
                                                                            g_.k(), simplif_cfg_.isec.max_ec_length_coefficient)),
@@ -286,17 +285,25 @@ class GraphSimplifier {
             PushValid(ATTipClipperInstance(g_, removal_handler_, info_container_.chunk_cnt()), "AT Tips", algos);
         }
 
+        PushValid(
+                LowCoverageEdgeRemoverInstance(g_,
+                                               simplif_cfg_.lcer,
+                                               info_container_),
+                "Removing edges with low coverage",
+                algos);
+
+        const size_t primary_launch_cnt = 2;
         size_t iteration = 0;
         bool enable_flag = true;
-        while (enable_flag) {
+        while (iteration < primary_launch_cnt || enable_flag) {
             enable_flag = false;
 
-            INFO("Iteration " << iteration);
+            INFO("Iteration " << iteration + 1);
 
             enable_flag |= FinalRemoveErroneousEdges();
             cnt_callback_.Report();
 
-            enable_flag |= RunAlgos(algos);
+            enable_flag |= RunAlgos(algos, iteration < primary_launch_cnt);
 
             iteration++;
 
@@ -401,7 +408,7 @@ public:
         //cannot stop simply if nothing changed, since threshold changes on every iteration
         while (iteration < simplif_cfg_.cycle_iter_count || graph_changed) {
             INFO("PROCEDURE == Simplification cycle, iteration " << iteration + 1);
-            graph_changed = RunAlgos(algos);
+            graph_changed = RunAlgos(algos, iteration == simplif_cfg_.cycle_iter_count - 1);
             ++iteration;
         }
 
@@ -536,8 +543,10 @@ void SimplificationCleanup::run(conj_graph_pack &gp, const char*) {
 
     auto isolated_edge_remover =
         IsolatedEdgeRemoverInstance(gp.g, cfg::get().simp.ier, info_container, (EdgeRemovalHandlerF<Graph>)nullptr);
-    if (isolated_edge_remover != nullptr)
+    if (isolated_edge_remover != nullptr) {
+        INFO("Removing isolated edges");
         isolated_edge_remover->Run();
+    }
 
     double low_threshold = gp.ginfo.trusted_bound();
     if (math::gr(low_threshold, 0.0)) {
