@@ -382,11 +382,12 @@ AlternativesAnalyzer<Graph> ParseBRConfig(const Graph &g,
     DEBUG("Length bound " << max_length);
 
     return AlternativesAnalyzer<Graph>(g, config.max_coverage,
-                                                    max_length,
-                                                    config.max_relative_coverage,
-                                                    config.max_delta,
-                                                    config.max_relative_delta,
-                                                    config.max_number_edges);
+                                       max_length,
+                                       config.max_relative_coverage,
+                                       config.max_delta,
+                                       config.max_relative_delta,
+                                       config.max_number_edges,
+                                       config.dijkstra_vertex_limit);
 }
 
 template<class Graph>
@@ -488,17 +489,21 @@ AlgoPtr<Graph> ComplexTipClipperInstance(Graph &g,
 
 template<class Graph>
 AlgoPtr<Graph> IsolatedEdgeRemoverInstance(Graph &g,
-                                           config::debruijn_config::simplification::isolated_edges_remover ier,
+                                           config::debruijn_config::simplification::isolated_edge_remover ier,
                                            const SimplifInfoContainer &info,
                                            EdgeRemovalHandlerF<Graph> removal_handler = 0) {
     if (!ier.enabled) {
         return nullptr;
     }
-    size_t max_length_any_cov = std::max(info.read_length(), ier.max_length_any_cov);
+    size_t max_length_any_cov = ier.use_rl_for_max_length_any_cov ?
+                                std::max(info.read_length(), ier.max_length_any_cov) : ier.max_length_any_cov;
+    size_t max_length = ier.use_rl_for_max_length ?
+                                std::max(info.read_length(), ier.max_length) : ier.max_length;
+
 
     auto condition = func::And(IsolatedEdgeCondition<Graph>(g),
                               func::Or(LengthUpperBound<Graph>(g, max_length_any_cov),
-                                      func::And(LengthUpperBound<Graph>(g, ier.max_length),
+                                      func::And(LengthUpperBound<Graph>(g, max_length),
                                                CoverageUpperBound<Graph>(g, ier.max_coverage))));
 
     return std::make_shared<omnigraph::ParallelEdgeRemovingAlgorithm<Graph>>(g,
@@ -608,15 +613,10 @@ AlgoPtr<Graph> BRInstance(Graph &g,
 
     auto alternatives_analyzer = ParseBRConfig(g, br_config);
 
-    auto candidate_finder = std::make_shared<omnigraph::ParallelInterestingElementFinder<Graph>>(
-                                                          omnigraph::NecessaryBulgeCondition(g,
-                                                                              alternatives_analyzer.max_length(),
-                                                                              alternatives_analyzer.max_coverage()),
-                                                          info.chunk_cnt());
     if (br_config.parallel) {
         INFO("Creating parallel br instance");
         return make_shared<omnigraph::ParallelBulgeRemover<Graph>>(g,
-                candidate_finder,
+                info.chunk_cnt(),
                 br_config.buff_size,
                 br_config.buff_cov_diff,
                 br_config.buff_cov_rel_diff,
@@ -627,7 +627,7 @@ AlgoPtr<Graph> BRInstance(Graph &g,
     } else {
         INFO("Creating br instance");
         return make_shared<omnigraph::BulgeRemover<Graph>>(g,
-                candidate_finder,
+                info.chunk_cnt(),
                 alternatives_analyzer,
                 nullptr,
                 removal_handler,
@@ -656,6 +656,25 @@ AlgoPtr<Graph> LowFlankDisconnectorInstance(Graph &g,
                                                                  removal_handler);
 }
 
+template<class Graph>
+AlgoPtr<Graph> LowCoverageEdgeRemoverInstance(Graph &g,
+                                              const config::debruijn_config::simplification::low_covered_edge_remover &lcer_config,
+                                              const SimplifInfoContainer &info) {
+    if (!lcer_config.enabled) {
+        return nullptr;
+    }
+    VERIFY(info.read_length() > g.k());
+    double threshold = lcer_config.coverage_threshold * double(info.read_length() - g.k()) / double(info.read_length());
+    INFO("Low coverage edge removal (LCER) activated and will remove edges of coverage lower than " << threshold);
+    return make_shared<ParallelEdgeRemovingAlgorithm<Graph, CoverageComparator<Graph>>>
+                        (g,
+                        CoverageUpperBound<Graph>(g, threshold),
+                        info.chunk_cnt(),
+                        (EdgeRemovalHandlerF<Graph>)nullptr,
+                        /*canonical_only*/true,
+                        CoverageComparator<Graph>(g));
+}
+
 template<class Graph>
 bool RemoveHiddenLoopEC(Graph &g,
                         const FlankingCoverage<Graph> &flanking_cov,
