@@ -8,7 +8,7 @@
 #pragma once
 
 #include "utils/standard_base.hpp"
-#include "utils/simple_tools.hpp"
+#include "utils/stl_utils.hpp"
 #include "comparison_utils.hpp"
 #include "boost/tokenizer.hpp"
 #include "coloring.hpp"
@@ -183,7 +183,7 @@ struct GeneCollection {
     size_t id = 0;
     for (string name : genome_names) {
     string filename = genomes_folder + name;
-    path::CheckFileExistenceFATAL(filename);
+    fs::CheckFileExistenceFATAL(filename);
     genomes.insert(
         make_pair(
             id,
@@ -199,7 +199,7 @@ GenomeId genome_id(const string& name) const {
 
 void LoadGenomes(const string& file_with_genomes,
     const string& genomes_folder) {
-  path::CheckFileExistenceFATAL(file_with_genomes);
+  fs::CheckFileExistenceFATAL(file_with_genomes);
   ifstream stream(file_with_genomes);
   set<string> genome_names;
   string name;
@@ -230,7 +230,7 @@ void SaveGeneInfo(const string& filename) const {
 }
 
 set<int> LoadGeneIDs(const string& file_with_ids) {
-  path::CheckFileExistenceFATAL(file_with_ids);
+  fs::CheckFileExistenceFATAL(file_with_ids);
   ifstream stream(file_with_ids);
   set<int> gene_ids;
   int id;
@@ -252,7 +252,7 @@ void AddGeneInfo(const GeneId& gene_id, const GenomeId& genome_id, const Range&
 void LoadGeneInfo(const string& filename, set<int> gene_ids) {
   using boost::tokenizer;
   using boost::escaped_list_separator;
-  path::CheckFileExistenceFATAL(filename);
+  fs::CheckFileExistenceFATAL(filename);
   ifstream stream(filename);
   string line;
   while (!stream.eof()) {
@@ -334,7 +334,7 @@ DECL_LOGGER("GeneCollection")
 //                       const ColorHandler<typename gp_t::graph_t>& coloring) {
 //  for (auto it = gene_collection.genes.begin();
 //      it != gene_collection.genes.end(); ++it) {
-////        make_dir(folder + ToString(it->first));
+////        make_dir(folder + std::to_string(it->first));
 //    const GenePositions& gene_poss = it->second.gene_positions;
 //
 //    //todo improve later
@@ -345,7 +345,7 @@ DECL_LOGGER("GeneCollection")
 //        total_gene_sequence = total_gene_sequence + genome.Subseq(pos.first.start_pos, pos.first.end_pos);
 //      }
 //    }
-//    WriteComponentsAlongSequence(gp, folder + ToString(it->first) + "/",
+//    WriteComponentsAlongSequence(gp, folder + std::to_string(it->first) + "/",
 //                                 100000, 50, total_gene_sequence, coloring);
 //  }
 //}
