@@ -7,7 +7,7 @@
 
 #include "config_struct.hpp"
 
-#include "utils/openmp_wrapper.h"
+#include "utils/parallel/openmp_wrapper.h"
 
 #include "llvm/Support/YAMLParser.h"
 #include "llvm/Support/YAMLTraits.h"
@@ -53,6 +53,7 @@ struct MappingTraits<corrector::corrector_config> {
         io.mapOptional("max_nthreads", cfg.max_nthreads, 1u);
         io.mapRequired("strategy", cfg.strat);
         io.mapOptional("bwa", cfg.bwa, std::string("."));
+        io.mapOptional("log_filename", cfg.log_filename, std::string("."));
     }
 };
 }}
