@@ -13,7 +13,7 @@
 #include "io/reads/osequencestream.hpp"
 #include "io/reads/file_reader.hpp"
 #include "io/reads/single_read.hpp"
-#include "utils/path_helper.hpp"
+#include "utils/filesystem/path_helper.hpp"
 
 #include <boost/algorithm/string.hpp>
 
@@ -34,7 +34,7 @@ void ContigProcessor::ReadContig() {
     contig_name_ = cur_read.name();
     contig_ = cur_read.GetSequenceString();
 
-    output_contig_file_ = path::append_path(path::parent_path(contig_file_), path::basename(contig_file_) + ".ref.fasta");
+    output_contig_file_ = fs::append_path(fs::parent_path(contig_file_), fs::basename(contig_file_) + ".ref.fasta");
     charts_.resize(contig_.length());
 }
 
@@ -74,8 +74,13 @@ size_t ContigProcessor::UpdateOneBase(size_t i, stringstream &ss, const unordere
         if (maxj != maxi) {
             DEBUG("Interesting positions differ with majority!");
             DEBUG("On position " << i << "  old: " << old << " majority: " << pos_to_var[maxi] << "interesting: " << pos_to_var[maxj]);
-            if (strat != Strategy::MajorityOnly)
-                maxi = maxj;
+            if (strat != Strategy::MajorityOnly) {
+                if (charts_[i].votes[maxj] > interesting_weight_cutoff)
+                    maxi = maxj;
+                else
+                    DEBUG(" alternative interesting position with weight " << charts_[i].votes[maxj] <<
+                          " fails weight cutoff");
+            }
         }
     }
     if (old != pos_to_var[maxi]) {
@@ -257,7 +262,19 @@ size_t ContigProcessor::ProcessMultipleSamFiles() {
         }
         sm.close();
     }
-
+    size_t total_coverage = 0;
+    for (const auto &pos: charts_)
+        total_coverage += pos.TotalMapped();
+    size_t average_coverage = total_coverage / contig_.length();
+    size_t different_cov = 0;
+    for (const auto &pos: charts_)
+        if ((pos.TotalMapped() < average_coverage / 2) || (pos.TotalMapped() > (average_coverage * 3) / 2))
+            different_cov++;
+    if (different_cov < contig_.length() * 3/ 10) {
+        interesting_weight_cutoff = int (average_coverage / 2);
+        DEBUG ("coverage is relatively uniform, average coverage is " << average_coverage
+               << " setting interesting positions heuristics to " << interesting_weight_cutoff);
+    }
     ipp_.FillInterestingPositions(charts_);
     for (const auto &sf : sam_files_) {
         MappedSamStream sm(sf.first);
@@ -285,7 +302,7 @@ size_t ContigProcessor::ProcessMultipleSamFiles() {
     }
     vector<string> contig_name_splitted;
     boost::split(contig_name_splitted, contig_name_, boost::is_any_of("_"));
-    io::osequencestream_simple oss(output_contig_file_);
+    io::OutputSequenceStream oss(output_contig_file_);
     for(size_t i = 0; i < contig_name_splitted.size(); i++) {
         if (contig_name_splitted[i] == "length" && i + 1 < contig_name_splitted.size()) {
             contig_name_splitted[i + 1] = std::to_string(int(s_new_contig.str().length()));
@@ -296,8 +313,7 @@ size_t ContigProcessor::ProcessMultipleSamFiles() {
     for(size_t i = 1; i < contig_name_splitted.size(); i++) {
         new_header += "_" + contig_name_splitted[i];
     }
-    oss.set_header(new_header);
-    oss << s_new_contig.str();
+    oss << io::SingleRead(new_header, s_new_contig.str());
 
     return total_changes;
 }
