@@ -7,10 +7,9 @@
 
 #pragma once
 
-#include "utils/path_helper.hpp"
+#include "utils/filesystem/path_helper.hpp"
 
 #include "io/reads/file_reader.hpp"
-#include "utils/path_helper.hpp"
 
 #include "pipeline/library.hpp"
 
@@ -46,10 +45,14 @@ class DatasetProcessor {
     std::unordered_map<size_t, std::string> lib_dirs_;
     const size_t kBuffSize = 100000;
     const size_t kMinContigLengthForInfo = 20000;
+
+protected:
+    DECL_LOGGER("DatasetProcessor")
+
 public:
     DatasetProcessor(const std::string &genome_file, const std::string &work_dir, const std::string &output_dir, const size_t &thread_num)
             : genome_file_(genome_file), work_dir_(work_dir), nthreads_(thread_num) {
-        output_contig_file_ = path::append_path(output_dir, "corrected_contigs.fasta");
+        output_contig_file_ = fs::append_path(output_dir, "corrected_contigs.fasta");
         buffered_count_ = 0;
     }
 
