@@ -14,7 +14,7 @@
 
 #include "config_struct_hammer.hpp"
 #include "pipeline/config_common.hpp"
-#include "utils/openmp_wrapper.h"
+#include "utils/parallel/openmp_wrapper.h"
 
 #include <boost/property_tree/ptree.hpp>
 #include <string>
