@@ -2,8 +2,9 @@
 from __future__ import print_function
 import sys
 import os
-import re
+import os.path
 from Bio import SeqIO
+from common import sample_name
 
 replace = False
 
@@ -13,16 +14,13 @@ if sys.argv[1] == "-r":
 else:
     files = sys.argv[1:]
 
-sample_re = re.compile("sample\d+")
-
 output = sys.stdout
 
 for file in files:
-    sample = sample_re.search(file).group(0)
     for seq in SeqIO.parse(file, "fasta"):
         seq_id = seq.id
         if replace:
             seq_id = seq_id.replace(",", "~")
-        seq.id = sample + "-" + seq_id
+        seq.id = sample_name(file) + "-" + seq_id
         seq.description = ""
         SeqIO.write(seq, output, "fasta")
