@@ -82,11 +82,11 @@ class DrawPolymorphicRegions : public DrawingCommand {
                         using namespace visualization::visualization_utils;
                         WriteComponentSinksSources(polymorphicRegion,
                                                    curr_env.folder() + "/" +
-                                                           ToString(curr_env.graph().int_id(*polymorphicRegion.vertices().begin())) + ".dot",
+                                                           std::to_string(curr_env.graph().int_id(*polymorphicRegion.vertices().begin())) + ".dot",
                                                    visualization::graph_colorer::DefaultColorer(curr_env.graph()),
                                                    curr_env.labeler());
 
-                        INFO("Component is written to " + curr_env.folder() + ToString(curr_env.graph().int_id(*polymorphicRegion.vertices().begin())) + ".dot");
+                        INFO("Component is written to " + curr_env.folder() + std::to_string(curr_env.graph().int_id(*polymorphicRegion.vertices().begin())) + ".dot");
                     }
 
                     i += curr_env.graph().length(positionSecond.first) - positionSecond.second;
