@@ -11,9 +11,9 @@
 
 #include "utils/segfault_handler.hpp"
 #include "utils/stacktrace.hpp"
-#include "utils/memory_limit.hpp"
-#include "utils/copy_file.hpp"
-#include "utils/perfcounter.hpp"
+#include "utils/perf/memory_limit.hpp"
+#include "utils/filesystem/copy_file.hpp"
+#include "utils/perf/perfcounter.hpp"
 #include "scaffold_correction.hpp"
 
 #include "pipeline/config_struct.hpp"
@@ -26,7 +26,7 @@
 //FIXME code duplication
 void load_config(const vector<string>& cfg_fns) {
     for (const auto& s : cfg_fns) {
-        path::CheckFileExistenceFATAL(s);
+        fs::CheckFileExistenceFATAL(s);
     }
 
     cfg::create_instance(cfg_fns);
@@ -49,16 +49,16 @@ void create_console_logger(string cfg_filename) {
 
     string log_props_file = cfg::get().log_filename;
 
-    if (!path::FileExists(log_props_file))
-        log_props_file = path::append_path(path::parent_path(cfg_filename), cfg::get().log_filename);
+    if (!fs::FileExists(log_props_file))
+        log_props_file = fs::append_path(fs::parent_path(cfg_filename), cfg::get().log_filename);
 
-    logger *lg = create_logger(path::FileExists(log_props_file) ? log_props_file : "");
+    logger *lg = create_logger(fs::FileExists(log_props_file) ? log_props_file : "");
     lg->add_writer(std::make_shared<console_writer>());
     attach_logger(lg);
 }
 
 int main(int argc, char** argv) {
-    perf_counter pc;
+    utils::perf_counter pc;
 
     const size_t GB = 1 << 30;
 
@@ -68,7 +68,7 @@ int main(int argc, char** argv) {
     try {
         using namespace debruijn_graph;
 
-        string cfg_dir = path::parent_path(argv[1]);
+        string cfg_dir = fs::parent_path(argv[1]);
 
         vector<string> cfg_fns;
         for (int i = 1; i < argc; ++i) {
@@ -83,7 +83,7 @@ int main(int argc, char** argv) {
 
         // read configuration file (dataset path etc.)
 
-        limit_memory(cfg::get().max_memory * GB);
+        utils::limit_memory(cfg::get().max_memory * GB);
 
         // assemble it!
         INFO("Assembling dataset (" << cfg::get().dataset_file << ") with K=" << cfg::get().K);
