@@ -9,10 +9,10 @@
 // Created by anton on 16.05.15.
 //
 
+#include "io/reads/file_reader.hpp"
 #include "stages/construction.hpp"
-#include "dev_support/standard_base.hpp"
+#include "utils/standard_base.hpp"
 #include "analysis_pipeline.hpp"
-#include "modules/io/reads_io/file_reader.hpp"
 
 spades::VariationDetectionStage::VariationDetectionStage(string output_file, const Config &config) : AssemblyStage("VariationDetection", "variation_detection"),
                                                                                                      output_file_(output_file), config_(config) {
@@ -138,4 +138,4 @@ vector <alignment_analysis::ConsistentMapping> spades::VariationDetectionStage::
         }
     }
     return result;
-}
\ No newline at end of file
+}
