@@ -10,13 +10,13 @@
  */
 #include "utils/logger/log_writers.hpp"
 #include "utils/segfault_handler.hpp"
-#include "utils/memory_limit.hpp"
-#include "utils/copy_file.hpp"
+#include "utils/perf/memory_limit.hpp"
+#include "utils/filesystem/copy_file.hpp"
 #include "pipeline/config_struct.hpp"
 #include "analysis_pipeline.hpp"
 
 void load_config(string cfg_filename) {
-    path::CheckFileExistenceFATAL(cfg_filename);
+    fs::CheckFileExistenceFATAL(cfg_filename);
 
     cfg::create_instance(cfg_filename);
 
@@ -38,16 +38,16 @@ void create_console_logger(string cfg_filename) {
 
     string log_props_file = cfg::get().log_filename;
 
-    if (!path::FileExists(log_props_file))
-        log_props_file = path::append_path(path::parent_path(cfg_filename), cfg::get().log_filename);
+    if (!fs::FileExists(log_props_file))
+        log_props_file = fs::append_path(fs::parent_path(cfg_filename), cfg::get().log_filename);
 
-    logger *lg = create_logger(path::FileExists(log_props_file) ? log_props_file : "");
+    logger *lg = create_logger(fs::FileExists(log_props_file) ? log_props_file : "");
     lg->add_writer(std::make_shared<console_writer>());
     attach_logger(lg);
 }
 
 int main(int /*argc*/, char** argv) {
-    perf_counter pc;
+    utils::perf_counter pc;
 
     const size_t GB = 1 << 30;
 
@@ -67,7 +67,7 @@ int main(int /*argc*/, char** argv) {
 
         // read configuration file (dataset path etc.)
 
-        limit_memory(cfg::get().max_memory * GB);
+        utils::limit_memory(cfg::get().max_memory * GB);
 
         // assemble it!
         INFO("Assembling dataset (" << cfg::get().dataset_file << ") with K=" << cfg::get().K);
