@@ -12,7 +12,7 @@ import sys
 import support
 from os.path import basename
 
-SUPPORTED_PYTHON_VERSIONS = ['2.4', '2.5', '2.6', '2.7', '3.2', '3.3', '3.4', '3.5']
+SUPPORTED_PYTHON_VERSIONS = ['2.4-2.7', '3.2+']  # major.minor format only, close ('-') and open ('+') ranges allowed
 # allowed reads extensions for BayesHammer and for thw whole SPAdes pipeline
 BH_ALLOWED_READS_EXTENSIONS = ['.fq', '.fastq', '.bam']
 CONTIGS_ALLOWED_READS_EXTENSIONS = ['.fa', '.fasta']
@@ -33,11 +33,12 @@ LONG_READS_TYPES = ["pacbio", "sanger", "nanopore", "tslr", "trusted-contigs", "
 contigs_name = "contigs.fasta"
 scaffolds_name = "scaffolds.fasta"
 assembly_graph_name = "assembly_graph.fastg"
-assembly_graph_name_gfa = "assembly_graph.gfa"
+assembly_graph_name_gfa = "assembly_graph_with_scaffolds.gfa"
 contigs_paths = "contigs.paths"
 scaffolds_paths = "scaffolds.paths"
 transcripts_name = "transcripts.fasta"
 transcripts_paths = "transcripts.paths"
+filtering_types = ["hard", "soft", "default"]
 
 #other constants
 MIN_K = 1
@@ -87,6 +88,7 @@ qvoffset = None  # auto-detect by default
 cov_cutoff = 'off'  # default is 'off'
 
 # hidden options
+save_gp = False
 mismatch_corrector = None
 reference = None
 series_analysis = None
@@ -95,6 +97,7 @@ iterations = None
 bh_heap_check = None
 spades_heap_check = None
 read_buffer_size = None
+lcer_cutoff = None 
 ### END OF OPTIONS
 
 # for restarting SPAdes
@@ -114,6 +117,7 @@ restart_developer_mode = None
 restart_reference = None
 restart_configs_dir = None
 restart_read_buffer_size = None
+restart_fast = None
 
 # for running to specific check-point
 stop_after = None
@@ -124,17 +128,22 @@ truseq_mode = False
 correct_scaffolds = False
 run_truseq_postprocessing = False
 
+#rna options
+strand_specific = None  # None, True, False are possible
+fast = None
+
 dict_of_prefixes = dict()
 dict_of_rel2abs = dict()
 
 # list of spades.py options
 long_options = "12= threads= memory= tmp-dir= iterations= phred-offset= sc iontorrent meta large-genome rna plasmid "\
+               "ss-fr ss-rf fast fast:false "\
                "only-error-correction only-assembler "\
                "disable-gzip-output disable-gzip-output:false disable-rr disable-rr:false " \
                "help version test debug debug:false reference= series-analysis= config-file= dataset= "\
                "bh-heap-check= spades-heap-check= read-buffer-size= help-hidden "\
-               "mismatch-correction mismatch-correction:false careful careful:false "\
-               "continue restart-from= diploid truseq cov-cutoff= configs-dir= stop-after=".split()
+               "mismatch-correction mismatch-correction:false careful careful:false save-gp save-gp:false "\
+               "continue restart-from= diploid truseq cov-cutoff= hidden-cov-cutoff= configs-dir= stop-after=".split()
 short_options = "o:1:2:s:k:t:m:i:hv"
 
 # adding multiple paired-end, mate-pair and other (long reads) libraries support
@@ -166,13 +175,13 @@ def get_mode():
 
 
 def version(spades_version, mode=None):
-    sys.stderr.write("SPAdes v" + str(spades_version))
+    sys.stdout.write("SPAdes v" + str(spades_version))
     if mode is None:
         mode = get_mode()
     if mode is not None:
-        sys.stderr.write(" [" + mode + "SPAdes mode]")
-    sys.stderr.write("\n")
-    sys.stderr.flush()
+        sys.stdout.write(" [" + mode + "SPAdes mode]")
+    sys.stdout.write("\n")
+    sys.stdout.flush()
 
 
 def usage(spades_version, show_hidden=False, mode=None):
@@ -247,12 +256,15 @@ def usage(spades_version, show_hidden=False, mode=None):
         sys.stderr.write("--sanger\t<filename>\tfile with Sanger reads\n")
         sys.stderr.write("--pacbio\t<filename>\tfile with PacBio reads\n")
         sys.stderr.write("--nanopore\t<filename>\tfile with Nanopore reads\n")
-    sys.stderr.write("--tslr\t<filename>\tfile with TSLR-contigs\n")
+    if not mode == "rna":
+        sys.stderr.write("--tslr\t<filename>\tfile with TSLR-contigs\n")
     sys.stderr.write("--trusted-contigs\t<filename>\tfile with trusted contigs\n")
     sys.stderr.write("--untrusted-contigs\t<filename>\tfile with untrusted contigs\n")
     if mode == "dip":
         sys.stderr.write("Input haplocontigs:" + "\n")
         sys.stderr.write("--hap\t<filename>\tfile with haplocontigs" + "\n")
+    if mode == "rna":
+        sys.stderr.write("--ss-<type>\tstrand specific data, <type> = fr (normal) and rf (antisense)\n")
 
     sys.stderr.write("" + "\n")
     sys.stderr.write("Pipeline options:" + "\n")
@@ -281,6 +293,8 @@ def usage(spades_version, show_hidden=False, mode=None):
     sys.stderr.write("" + "\n")
     sys.stderr.write("Advanced options:" + "\n")
     sys.stderr.write("--dataset\t<filename>\tfile with dataset description in YAML format" + "\n")
+    if mode == "rna":
+        sys.stderr.write("--fast\t\t\t\tspeeds up isoform detection, but may miss short and low-expressed isoforms\n")
     sys.stderr.write("-t/--threads\t<int>\t\tnumber of threads" + "\n")
     sys.stderr.write("\t\t\t\t[default: %s]\n" % THREADS)
     sys.stderr.write("-m/--memory\t<int>\t\tRAM limit for SPAdes in Gb"\
@@ -294,7 +308,7 @@ def usage(spades_version, show_hidden=False, mode=None):
         sys.stderr.write("\t\t\t\tless than " + str(MAX_K + 1) + ") [default: 'auto']" + "\n")
     else:
         sys.stderr.write("-k\t\t<int>\t\tk-mer size (must be odd and less than " + str(MAX_K + 1) + ") " \
-                         "[default: " + str(K_MERS_RNA[0]) + "]\n")
+                         "[default: 'auto']\n")
 
     if mode not in ["rna", "meta"]:
         sys.stderr.write("--cov-cutoff\t<float>\t\tcoverage cutoff value (a positive float number, "
@@ -323,6 +337,9 @@ def usage(spades_version, show_hidden=False, mode=None):
         sys.stderr.write("--spades-heap-check\t<value>\tsets HEAPCHECK environment variable"\
                              " for SPAdes" + "\n")
         sys.stderr.write("--large-genome\tEnables optimizations for large genomes \n")
+        sys.stderr.write("--save-gp\tEnables saving graph pack before repeat resolution (even without --debug) \n")
+        sys.stderr.write("--hidden-cov-cutoff\t<float>\t\tcoverage cutoff value deeply integrated in simplification"\
+                            " (a positive float number). Base coverage! Will be adjusted depending on K and RL! \n")
         sys.stderr.write("--help-hidden\tprints this usage message with all hidden options" + "\n")
 
     if show_hidden and mode == "dip":
@@ -354,6 +371,7 @@ def set_default_values():
     global qvoffset
     global cov_cutoff
     global tmp_dir
+    global fast
 
     if threads is None:
         threads = THREADS
@@ -380,12 +398,15 @@ def set_default_values():
         cov_cutoff = 'off'
     if tmp_dir is None:
         tmp_dir = os.path.join(output_dir, TMP_DIR)
+    if fast is None:
+        fast = False
 
 
 def set_test_options():
     global output_dir
     global single_cell
     global test_mode
+    global meta
 
     output_dir = os.path.abspath('spades_test')
     single_cell = False
@@ -406,6 +427,8 @@ def save_restart_options(log):
         support.error("you cannot specify --only-assembler with --restart-from option!", log)
     if only_error_correction:
         support.error("you cannot specify --only-error-correction with --restart-from option!", log)
+    if strand_specific is not None:
+        support.error("you cannot specify strand specificity (--ss-rf or --ss-fr) with --restart-from option!", log)
 
     global restart_k_mers
     global restart_careful
@@ -421,6 +444,7 @@ def save_restart_options(log):
     global restart_reference
     global restart_configs_dir
     global restart_read_buffer_size
+    global restart_fast
 
     restart_k_mers = k_mers
     restart_careful = careful
@@ -436,6 +460,7 @@ def save_restart_options(log):
     restart_reference = reference
     restart_configs_dir = configs_dir
     restart_read_buffer_size = read_buffer_size
+    restart_fast = fast
 
 
 def load_restart_options():
@@ -454,6 +479,7 @@ def load_restart_options():
     global configs_dir
     global read_buffer_size
     global original_k_mers
+    global fast
 
     if restart_k_mers:
         original_k_mers = k_mers
@@ -487,6 +513,8 @@ def load_restart_options():
         configs_dir = restart_configs_dir
     if restart_read_buffer_size is not None:
         read_buffer_size = restart_read_buffer_size
+    if restart_fast is not None:
+        fast = restart_fast
 
 
 def enable_truseq_mode():
