@@ -43,6 +43,7 @@ def prepare_config_spades(filename, cfg, log, additional_contigs_fname, K, stage
 #    subst_dict["topology_simplif_enabled"] = bool_to_str(last_one)
     subst_dict["max_threads"] = cfg.max_threads
     subst_dict["max_memory"] = cfg.max_memory
+    subst_dict["save_gp"] = bool_to_str(cfg.save_gp)
     if (not last_one):
         subst_dict["correct_mismatches"] = bool_to_str(False)
     if "resolving_mode" in cfg.__dict__:
@@ -58,6 +59,9 @@ def prepare_config_spades(filename, cfg, log, additional_contigs_fname, K, stage
             subst_dict["coverage_threshold"] = 0.0
         else:
             subst_dict["coverage_threshold"] = cfg.cov_cutoff
+    if cfg.lcer_cutoff is not None:
+        subst_dict["lcer_enabled"] = bool_to_str(True)
+        subst_dict["lcer_coverage_threshold"] = cfg.lcer_cutoff
 
     #TODO: make something about spades.py and config param substitution 
     if "bwa_paired" in cfg.__dict__:
@@ -68,6 +72,15 @@ def prepare_config_spades(filename, cfg, log, additional_contigs_fname, K, stage
     process_cfg.substitute_params(filename, subst_dict, log)
 
 
+def prepare_config_rnaspades(filename, log):
+    if not options_storage.rna:
+        return
+    subst_dict = dict()
+    subst_dict["ss_enabled"] = bool_to_str(options_storage.strand_specific is not None)
+    subst_dict["antisense"] = bool_to_str(options_storage.strand_specific)
+    process_cfg.substitute_params(filename, subst_dict, log)
+
+
 def get_read_length(output_dir, K, ext_python_modules_home, log):
     est_params_filename = os.path.join(output_dir, "K%d" % K, "final.lib_data")
     max_read_length = 0
@@ -119,6 +132,7 @@ def reveal_original_k_mers(RL):
     original_k_mers = [k for k in original_k_mers if k < RL]
     return original_k_mers
 
+
 def add_configs(command, configs_dir):
     #Order matters here!
     mode_config_mapping = [("single_cell", "mda_mode"), 
@@ -127,13 +141,22 @@ def add_configs(command, configs_dir):
                            ("rna", "rna_mode"),
                            ("large_genome", "large_genome_mode"),
                            ("plasmid", "plasmid_mode"),
-                           ("careful", "careful_mode"),
+                           #("careful", "careful_mode"),
                            ("diploid_mode", "diploid_mode")]
     for (mode, config) in mode_config_mapping:
         if options_storage.__dict__[mode]:
             if mode == "rna" or mode == "meta":
                 command.append(os.path.join(configs_dir, "mda_mode.info"))
             command.append(os.path.join(configs_dir, config + ".info"))
+    if options_storage.__dict__["careful"]:
+        if options_storage.__dict__["single_cell"]:
+            command.append(os.path.join(configs_dir, "careful_mda_mode.info"))
+        else:
+            command.append(os.path.join(configs_dir, "careful_mode.info"))
+
+    # special case: extra config
+    if options_storage.rna and options_storage.fast:
+        command.append(os.path.join(configs_dir, "rna_fast_mode.info"))
     
 
 def run_iteration(configs_dir, execution_home, cfg, log, K, prev_K, last_one):
@@ -178,6 +201,7 @@ def run_iteration(configs_dir, execution_home, cfg, log, K, prev_K, last_one):
         #FIXME why here???
         process_cfg.substitute_params(os.path.join(dst_configs, "pe_params.info"), {"scaffolding_mode": cfg.scaffolding_mode}, log)
 
+    prepare_config_rnaspades(os.path.join(dst_configs, "rna_mode.info"), log)
     cfg_fn = os.path.join(dst_configs, "config.info")
     prepare_config_spades(cfg_fn, cfg, log, additional_contigs_fname, K, stage, saves_dir, last_one, execution_home)
 
@@ -347,11 +371,18 @@ def run_spades(configs_dir, execution_home, cfg, dataset_data, ext_python_module
                 shutil.copyfile(os.path.join(latest, "before_rr.fasta"), result_before_rr_contigs)
         if options_storage.rna:
             if os.path.isfile(os.path.join(latest, "transcripts.fasta")):
-                    if not os.path.isfile(cfg.result_transcripts) or not options_storage.continue_mode:
-                        shutil.copyfile(os.path.join(latest, "transcripts.fasta"), cfg.result_transcripts)
+                if not os.path.isfile(cfg.result_transcripts) or not options_storage.continue_mode:
+                    shutil.copyfile(os.path.join(latest, "transcripts.fasta"), cfg.result_transcripts)
             if os.path.isfile(os.path.join(latest, "transcripts.paths")):
                 if not os.path.isfile(cfg.result_transcripts_paths) or not options_storage.continue_mode:
                     shutil.copyfile(os.path.join(latest, "transcripts.paths"), cfg.result_transcripts_paths)
+            for filtering_type in options_storage.filtering_types:
+                prefix = filtering_type + "_filtered_"
+                result_filtered_transcripts = os.path.join(cfg.output_dir, prefix + options_storage.transcripts_name)
+                latest_filtered_transcripts = os.path.join(latest, prefix + "final_paths.fasta")
+                if os.path.isfile(latest_filtered_transcripts):
+                    if not os.path.isfile(result_filtered_transcripts) or not options_storage.continue_mode:
+                        shutil.copyfile(latest_filtered_transcripts, result_filtered_transcripts)
         else:
             if os.path.isfile(os.path.join(latest, "final_contigs.fasta")):
                 if not os.path.isfile(cfg.result_contigs) or not options_storage.continue_mode:
@@ -367,9 +398,9 @@ def run_spades(configs_dir, execution_home, cfg, dataset_data, ext_python_module
                 if os.path.isfile(os.path.join(latest, "scaffolds.paths")):
                     if not os.path.isfile(cfg.result_scaffolds_paths) or not options_storage.continue_mode:
                         shutil.copyfile(os.path.join(latest, "scaffolds.paths"), cfg.result_scaffolds_paths)
-            if os.path.isfile(os.path.join(latest, "assembly_graph.gfa")):
+            if os.path.isfile(os.path.join(latest, "assembly_graph_with_scaffolds.gfa")):
                 if not os.path.isfile(cfg.result_graph_gfa) or not options_storage.continue_mode:
-                    shutil.copyfile(os.path.join(latest, "assembly_graph.gfa"), cfg.result_graph_gfa)
+                    shutil.copyfile(os.path.join(latest, "assembly_graph_with_scaffolds.gfa"), cfg.result_graph_gfa)
             if os.path.isfile(os.path.join(latest, "assembly_graph.fastg")):
                 if not os.path.isfile(cfg.result_graph) or not options_storage.continue_mode:
                     shutil.copyfile(os.path.join(latest, "assembly_graph.fastg"), cfg.result_graph)
