@@ -18,7 +18,10 @@ import tempfile
 import shutil
 import options_storage
 import itertools
+from common import SeqIO
+import math
 from os.path import abspath, expanduser, join
+from distutils.version import LooseVersion
 
 # constants to print and detect warnings and errors in logs
 SPADES_PY_ERROR_MESSAGE = "== Error == "
@@ -40,10 +43,12 @@ def error(err_str, log=None, dipspades=False, prefix=SPADES_PY_ERROR_MESSAGE):
         log.info("\n\n" + prefix + " " + err_str)
         log_warnings(log, with_error=True)
         log.info("\nIn case you have troubles running " + binary_name + ", you can write to spades.support@cab.spbu.ru")
+        log.info("or report an issue on our GitHub repository github.com/ablab/spades")
         log.info("Please provide us with params.txt and " + binary_name.lower() + ".log files from the output directory.")
     else:
         sys.stderr.write("\n\n" + prefix + " " + err_str + "\n\n")
         sys.stderr.write("\nIn case you have troubles running " + binary_name + ", you can write to spades.support@cab.spbu.ru\n")
+        sys.stderr.write("or report an issue on our GitHub repository github.com/ablab/spades\n")
         sys.stderr.write("Please provide us with params.txt and " + binary_name.lower() + ".log files from the output directory.\n")
         sys.stderr.flush()
     if current_tmp_dir and os.path.isdir(current_tmp_dir):
@@ -60,14 +65,35 @@ def warning(warn_str, log=None, prefix="== Warning == "):
 
 
 def check_python_version():
-    if sys.version[0:3] not in options_storage.SUPPORTED_PYTHON_VERSIONS:
-        error("python version " + sys.version[0:3] + " is not supported!\n" + \
-              "Supported versions are " + ", ".join(options_storage.SUPPORTED_PYTHON_VERSIONS))
+    def __next_version(version):
+        components = version.split('.')
+        for i in reversed(range(len(components))):
+            if components[i].isdigit():
+                components[i] = str(int(components[i]) + 1)
+                break
+        return '.'.join(components)
+
+    current_version = sys.version.split()[0]
+    supported_versions_msg = []
+    for supported_versions in options_storage.SUPPORTED_PYTHON_VERSIONS:
+        major = supported_versions[0]
+        if '-' in supported_versions:  # range
+            min_inc, max_inc = supported_versions.split('-')
+        elif supported_versions.endswith('+'):  # half open range
+            min_inc, max_inc = supported_versions[:-1], major
+        else:  # exact version
+            min_inc = max_inc = supported_versions
+        max_exc = __next_version(max_inc)
+        supported_versions_msg.append("Python%s: %s" % (major, supported_versions.replace('+', " and higher")))
+        if LooseVersion(min_inc) <= LooseVersion(current_version) < LooseVersion(max_exc):
+            return True
+    error("Python version " + current_version + " is not supported!\n" +
+          "Supported versions are " + ", ".join(supported_versions_msg))
 
 
 def get_spades_binaries_info_message():
     return "You can obtain SPAdes binaries in one of two ways:" +\
-           "\n1. Download them from http://bioinf.spbau.ru/content/spades-download" +\
+           "\n1. Download them from http://cab.spbu.ru/software/spades/" +\
            "\n2. Build source code with ./spades_compile.sh script"
 
 
@@ -577,6 +603,36 @@ def relative2abs_paths(dataset_data, dirname):
     return abs_paths_dataset_data
 
 
+def get_reads_length(dataset_data, log, num_checked=10 ** 4, diff_len_allowable=25):
+    max_reads_lenghts = [get_max_reads_length(reads_file, log, num_checked) for reads_file in get_reads_files(dataset_data)]
+
+    avg_len = sum(max_reads_lenghts) / len(max_reads_lenghts)
+    for max_len in max_reads_lenghts:
+        if math.fabs(max_len - avg_len) > diff_len_allowable:
+            warning('Read lengths differ more than allowable. Length: ' + str(max_len) + '. Avg. length: ' + str(avg_len) + '.', log)
+    reads_length = min(max_reads_lenghts)
+    log.info('Reads length: ' + str(reads_length))
+    return reads_length
+
+
+def get_reads_files(dataset_data):
+    for reads_library in dataset_data:
+        for key, value in reads_library.items():
+            if key.endswith('reads'):
+                for reads_file in value:
+                    yield reads_file
+
+
+def get_max_reads_length(reads_file, log, num_checked):
+    file_type = SeqIO.get_read_file_type(reads_file)
+    if not file_type:
+        error('Incorrect type of reads file: ' + reads_file, log)
+
+    max_reads_length = max([len(rec) for rec in itertools.islice(SeqIO.parse(SeqIO.Open(reads_file, "r"), file_type), num_checked)])
+    log.info('Max reads length: ' + str(max_reads_length))
+    return max_reads_length
+
+
 def check_dataset_reads(dataset_data, only_assembler, log):
     all_files = []
     for id, reads_library in enumerate(dataset_data):
